#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MultiDataOpenResult(object):

    def __init__(self):
        self._avg_num = None
        self._feature_key = None
        self._object_id = None
        self._object_name = None
        self._object_type = None
        self._user_cnt = None
        self._user_ratio = None

    @property
    def avg_num(self):
        return self._avg_num

    @avg_num.setter
    def avg_num(self, value):
        self._avg_num = value
    @property
    def feature_key(self):
        return self._feature_key

    @feature_key.setter
    def feature_key(self, value):
        self._feature_key = value
    @property
    def object_id(self):
        return self._object_id

    @object_id.setter
    def object_id(self, value):
        self._object_id = value
    @property
    def object_name(self):
        return self._object_name

    @object_name.setter
    def object_name(self, value):
        self._object_name = value
    @property
    def object_type(self):
        return self._object_type

    @object_type.setter
    def object_type(self, value):
        self._object_type = value
    @property
    def user_cnt(self):
        return self._user_cnt

    @user_cnt.setter
    def user_cnt(self, value):
        self._user_cnt = value
    @property
    def user_ratio(self):
        return self._user_ratio

    @user_ratio.setter
    def user_ratio(self, value):
        self._user_ratio = value


    def to_alipay_dict(self):
        params = dict()
        if self.avg_num:
            if hasattr(self.avg_num, 'to_alipay_dict'):
                params['avg_num'] = self.avg_num.to_alipay_dict()
            else:
                params['avg_num'] = self.avg_num
        if self.feature_key:
            if hasattr(self.feature_key, 'to_alipay_dict'):
                params['feature_key'] = self.feature_key.to_alipay_dict()
            else:
                params['feature_key'] = self.feature_key
        if self.object_id:
            if hasattr(self.object_id, 'to_alipay_dict'):
                params['object_id'] = self.object_id.to_alipay_dict()
            else:
                params['object_id'] = self.object_id
        if self.object_name:
            if hasattr(self.object_name, 'to_alipay_dict'):
                params['object_name'] = self.object_name.to_alipay_dict()
            else:
                params['object_name'] = self.object_name
        if self.object_type:
            if hasattr(self.object_type, 'to_alipay_dict'):
                params['object_type'] = self.object_type.to_alipay_dict()
            else:
                params['object_type'] = self.object_type
        if self.user_cnt:
            if hasattr(self.user_cnt, 'to_alipay_dict'):
                params['user_cnt'] = self.user_cnt.to_alipay_dict()
            else:
                params['user_cnt'] = self.user_cnt
        if self.user_ratio:
            if hasattr(self.user_ratio, 'to_alipay_dict'):
                params['user_ratio'] = self.user_ratio.to_alipay_dict()
            else:
                params['user_ratio'] = self.user_ratio
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MultiDataOpenResult()
        if 'avg_num' in d:
            o.avg_num = d['avg_num']
        if 'feature_key' in d:
            o.feature_key = d['feature_key']
        if 'object_id' in d:
            o.object_id = d['object_id']
        if 'object_name' in d:
            o.object_name = d['object_name']
        if 'object_type' in d:
            o.object_type = d['object_type']
        if 'user_cnt' in d:
            o.user_cnt = d['user_cnt']
        if 'user_ratio' in d:
            o.user_ratio = d['user_ratio']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaMerchantCreditserviceDetailQueryModel(object):

    def __init__(self):
        self._credit_service_id = None
        self._version_no = None

    @property
    def credit_service_id(self):
        return self._credit_service_id

    @credit_service_id.setter
    def credit_service_id(self, value):
        self._credit_service_id = value
    @property
    def version_no(self):
        return self._version_no

    @version_no.setter
    def version_no(self, value):
        self._version_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.credit_service_id:
            if hasattr(self.credit_service_id, 'to_alipay_dict'):
                params['credit_service_id'] = self.credit_service_id.to_alipay_dict()
            else:
                params['credit_service_id'] = self.credit_service_id
        if self.version_no:
            if hasattr(self.version_no, 'to_alipay_dict'):
                params['version_no'] = self.version_no.to_alipay_dict()
            else:
                params['version_no'] = self.version_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaMerchantCreditserviceDetailQueryModel()
        if 'credit_service_id' in d:
            o.credit_service_id = d['credit_service_id']
        if 'version_no' in d:
            o.version_no = d['version_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoCityserviceOpeneventAppstatusModifyModel(object):

    def __init__(self):
        self._app_code = None
        self._reason = None
        self._status = None

    @property
    def app_code(self):
        return self._app_code

    @app_code.setter
    def app_code(self, value):
        self._app_code = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_code:
            if hasattr(self.app_code, 'to_alipay_dict'):
                params['app_code'] = self.app_code.to_alipay_dict()
            else:
                params['app_code'] = self.app_code
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoCityserviceOpeneventAppstatusModifyModel()
        if 'app_code' in d:
            o.app_code = d['app_code']
        if 'reason' in d:
            o.reason = d['reason']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherAvailableAccountInfo import VoucherAvailableAccountInfo
from alipay.aop.api.domain.VoucherAvailableAppInfo import VoucherAvailableAppInfo
from alipay.aop.api.domain.VoucherAvailableGeographyScopeInfo import VoucherAvailableGeographyScopeInfo
from alipay.aop.api.domain.VoucherAvailableGoodsInfo import VoucherAvailableGoodsInfo


class VoucherAvailableScopeInfo(object):

    def __init__(self):
        self._voucher_available_account_info = None
        self._voucher_available_app_info = None
        self._voucher_available_geography_scope_info = None
        self._voucher_available_goods_info = None

    @property
    def voucher_available_account_info(self):
        return self._voucher_available_account_info

    @voucher_available_account_info.setter
    def voucher_available_account_info(self, value):
        if isinstance(value, VoucherAvailableAccountInfo):
            self._voucher_available_account_info = value
        else:
            self._voucher_available_account_info = VoucherAvailableAccountInfo.from_alipay_dict(value)
    @property
    def voucher_available_app_info(self):
        return self._voucher_available_app_info

    @voucher_available_app_info.setter
    def voucher_available_app_info(self, value):
        if isinstance(value, VoucherAvailableAppInfo):
            self._voucher_available_app_info = value
        else:
            self._voucher_available_app_info = VoucherAvailableAppInfo.from_alipay_dict(value)
    @property
    def voucher_available_geography_scope_info(self):
        return self._voucher_available_geography_scope_info

    @voucher_available_geography_scope_info.setter
    def voucher_available_geography_scope_info(self, value):
        if isinstance(value, VoucherAvailableGeographyScopeInfo):
            self._voucher_available_geography_scope_info = value
        else:
            self._voucher_available_geography_scope_info = VoucherAvailableGeographyScopeInfo.from_alipay_dict(value)
    @property
    def voucher_available_goods_info(self):
        return self._voucher_available_goods_info

    @voucher_available_goods_info.setter
    def voucher_available_goods_info(self, value):
        if isinstance(value, VoucherAvailableGoodsInfo):
            self._voucher_available_goods_info = value
        else:
            self._voucher_available_goods_info = VoucherAvailableGoodsInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.voucher_available_account_info:
            if hasattr(self.voucher_available_account_info, 'to_alipay_dict'):
                params['voucher_available_account_info'] = self.voucher_available_account_info.to_alipay_dict()
            else:
                params['voucher_available_account_info'] = self.voucher_available_account_info
        if self.voucher_available_app_info:
            if hasattr(self.voucher_available_app_info, 'to_alipay_dict'):
                params['voucher_available_app_info'] = self.voucher_available_app_info.to_alipay_dict()
            else:
                params['voucher_available_app_info'] = self.voucher_available_app_info
        if self.voucher_available_geography_scope_info:
            if hasattr(self.voucher_available_geography_scope_info, 'to_alipay_dict'):
                params['voucher_available_geography_scope_info'] = self.voucher_available_geography_scope_info.to_alipay_dict()
            else:
                params['voucher_available_geography_scope_info'] = self.voucher_available_geography_scope_info
        if self.voucher_available_goods_info:
            if hasattr(self.voucher_available_goods_info, 'to_alipay_dict'):
                params['voucher_available_goods_info'] = self.voucher_available_goods_info.to_alipay_dict()
            else:
                params['voucher_available_goods_info'] = self.voucher_available_goods_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherAvailableScopeInfo()
        if 'voucher_available_account_info' in d:
            o.voucher_available_account_info = d['voucher_available_account_info']
        if 'voucher_available_app_info' in d:
            o.voucher_available_app_info = d['voucher_available_app_info']
        if 'voucher_available_geography_scope_info' in d:
            o.voucher_available_geography_scope_info = d['voucher_available_geography_scope_info']
        if 'voucher_available_goods_info' in d:
            o.voucher_available_goods_info = d['voucher_available_goods_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CreditpaySubquota import CreditpaySubquota


class MybankCreditSupplychainCreditpayAmountQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSupplychainCreditpayAmountQueryResponse, self).__init__()
        self._admit = None
        self._available_amt = None
        self._buyer_scene_id = None
        self._creditpay_sub_quotas = None
        self._signed = None
        self._total_amt = None
        self._trace_id = None

    @property
    def admit(self):
        return self._admit

    @admit.setter
    def admit(self, value):
        self._admit = value
    @property
    def available_amt(self):
        return self._available_amt

    @available_amt.setter
    def available_amt(self, value):
        self._available_amt = value
    @property
    def buyer_scene_id(self):
        return self._buyer_scene_id

    @buyer_scene_id.setter
    def buyer_scene_id(self, value):
        self._buyer_scene_id = value
    @property
    def creditpay_sub_quotas(self):
        return self._creditpay_sub_quotas

    @creditpay_sub_quotas.setter
    def creditpay_sub_quotas(self, value):
        if isinstance(value, list):
            self._creditpay_sub_quotas = list()
            for i in value:
                if isinstance(i, CreditpaySubquota):
                    self._creditpay_sub_quotas.append(i)
                else:
                    self._creditpay_sub_quotas.append(CreditpaySubquota.from_alipay_dict(i))
    @property
    def signed(self):
        return self._signed

    @signed.setter
    def signed(self, value):
        self._signed = value
    @property
    def total_amt(self):
        return self._total_amt

    @total_amt.setter
    def total_amt(self, value):
        self._total_amt = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSupplychainCreditpayAmountQueryResponse, self).parse_response_content(response_content)
        if 'admit' in response:
            self.admit = response['admit']
        if 'available_amt' in response:
            self.available_amt = response['available_amt']
        if 'buyer_scene_id' in response:
            self.buyer_scene_id = response['buyer_scene_id']
        if 'creditpay_sub_quotas' in response:
            self.creditpay_sub_quotas = response['creditpay_sub_quotas']
        if 'signed' in response:
            self.signed = response['signed']
        if 'total_amt' in response:
            self.total_amt = response['total_amt']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GoodsPos import GoodsPos


class WeightFloor(object):

    def __init__(self):
        self._floor_id = None
        self._goods_list = None

    @property
    def floor_id(self):
        return self._floor_id

    @floor_id.setter
    def floor_id(self, value):
        self._floor_id = value
    @property
    def goods_list(self):
        return self._goods_list

    @goods_list.setter
    def goods_list(self, value):
        if isinstance(value, list):
            self._goods_list = list()
            for i in value:
                if isinstance(i, GoodsPos):
                    self._goods_list.append(i)
                else:
                    self._goods_list.append(GoodsPos.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.floor_id:
            if hasattr(self.floor_id, 'to_alipay_dict'):
                params['floor_id'] = self.floor_id.to_alipay_dict()
            else:
                params['floor_id'] = self.floor_id
        if self.goods_list:
            if isinstance(self.goods_list, list):
                for i in range(0, len(self.goods_list)):
                    element = self.goods_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_list[i] = element.to_alipay_dict()
            if hasattr(self.goods_list, 'to_alipay_dict'):
                params['goods_list'] = self.goods_list.to_alipay_dict()
            else:
                params['goods_list'] = self.goods_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WeightFloor()
        if 'floor_id' in d:
            o.floor_id = d['floor_id']
        if 'goods_list' in d:
            o.goods_list = d['goods_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.QYBMapInfo import QYBMapInfo


class FinEquityInfo(object):

    def __init__(self):
        self._end_time = None
        self._equity_code = None
        self._equity_num = None
        self._equity_type = None
        self._product_code = None
        self._remark = None
        self._start_time = None
        self._status = None
        self._verification_info = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def equity_code(self):
        return self._equity_code

    @equity_code.setter
    def equity_code(self, value):
        self._equity_code = value
    @property
    def equity_num(self):
        return self._equity_num

    @equity_num.setter
    def equity_num(self, value):
        self._equity_num = value
    @property
    def equity_type(self):
        return self._equity_type

    @equity_type.setter
    def equity_type(self, value):
        self._equity_type = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def verification_info(self):
        return self._verification_info

    @verification_info.setter
    def verification_info(self, value):
        if isinstance(value, QYBMapInfo):
            self._verification_info = value
        else:
            self._verification_info = QYBMapInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.equity_code:
            if hasattr(self.equity_code, 'to_alipay_dict'):
                params['equity_code'] = self.equity_code.to_alipay_dict()
            else:
                params['equity_code'] = self.equity_code
        if self.equity_num:
            if hasattr(self.equity_num, 'to_alipay_dict'):
                params['equity_num'] = self.equity_num.to_alipay_dict()
            else:
                params['equity_num'] = self.equity_num
        if self.equity_type:
            if hasattr(self.equity_type, 'to_alipay_dict'):
                params['equity_type'] = self.equity_type.to_alipay_dict()
            else:
                params['equity_type'] = self.equity_type
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.verification_info:
            if hasattr(self.verification_info, 'to_alipay_dict'):
                params['verification_info'] = self.verification_info.to_alipay_dict()
            else:
                params['verification_info'] = self.verification_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FinEquityInfo()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'equity_code' in d:
            o.equity_code = d['equity_code']
        if 'equity_num' in d:
            o.equity_num = d['equity_num']
        if 'equity_type' in d:
            o.equity_type = d['equity_type']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'remark' in d:
            o.remark = d['remark']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'status' in d:
            o.status = d['status']
        if 'verification_info' in d:
            o.verification_info = d['verification_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniAmpeTracerSyncModel(object):

    def __init__(self):
        self._device_id = None
        self._product_id = None
        self._spm_a = None
        self._spm_b = None
        self._spm_c = None
        self._spm_d = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value
    @property
    def spm_a(self):
        return self._spm_a

    @spm_a.setter
    def spm_a(self, value):
        self._spm_a = value
    @property
    def spm_b(self):
        return self._spm_b

    @spm_b.setter
    def spm_b(self, value):
        self._spm_b = value
    @property
    def spm_c(self):
        return self._spm_c

    @spm_c.setter
    def spm_c(self, value):
        self._spm_c = value
    @property
    def spm_d(self):
        return self._spm_d

    @spm_d.setter
    def spm_d(self, value):
        self._spm_d = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.spm_a:
            if hasattr(self.spm_a, 'to_alipay_dict'):
                params['spm_a'] = self.spm_a.to_alipay_dict()
            else:
                params['spm_a'] = self.spm_a
        if self.spm_b:
            if hasattr(self.spm_b, 'to_alipay_dict'):
                params['spm_b'] = self.spm_b.to_alipay_dict()
            else:
                params['spm_b'] = self.spm_b
        if self.spm_c:
            if hasattr(self.spm_c, 'to_alipay_dict'):
                params['spm_c'] = self.spm_c.to_alipay_dict()
            else:
                params['spm_c'] = self.spm_c
        if self.spm_d:
            if hasattr(self.spm_d, 'to_alipay_dict'):
                params['spm_d'] = self.spm_d.to_alipay_dict()
            else:
                params['spm_d'] = self.spm_d
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniAmpeTracerSyncModel()
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'spm_a' in d:
            o.spm_a = d['spm_a']
        if 'spm_b' in d:
            o.spm_b = d['spm_b']
        if 'spm_c' in d:
            o.spm_c = d['spm_c']
        if 'spm_d' in d:
            o.spm_d = d['spm_d']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ArchiveFaceExtInfo import ArchiveFaceExtInfo


class AlipayUserAntarchiveFaceUploadModel(object):

    def __init__(self):
        self._biz_scene = None
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._ext_info = None
        self._other_portrait_url = None
        self._portrait_url = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, ArchiveFaceExtInfo):
            self._ext_info = value
        else:
            self._ext_info = ArchiveFaceExtInfo.from_alipay_dict(value)
    @property
    def other_portrait_url(self):
        return self._other_portrait_url

    @other_portrait_url.setter
    def other_portrait_url(self, value):
        self._other_portrait_url = value
    @property
    def portrait_url(self):
        return self._portrait_url

    @portrait_url.setter
    def portrait_url(self, value):
        self._portrait_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.other_portrait_url:
            if hasattr(self.other_portrait_url, 'to_alipay_dict'):
                params['other_portrait_url'] = self.other_portrait_url.to_alipay_dict()
            else:
                params['other_portrait_url'] = self.other_portrait_url
        if self.portrait_url:
            if hasattr(self.portrait_url, 'to_alipay_dict'):
                params['portrait_url'] = self.portrait_url.to_alipay_dict()
            else:
                params['portrait_url'] = self.portrait_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAntarchiveFaceUploadModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'other_portrait_url' in d:
            o.other_portrait_url = d['other_portrait_url']
        if 'portrait_url' in d:
            o.portrait_url = d['portrait_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankEcnyTradeQrcodecreateModel(object):

    def __init__(self):
        self._amount = None
        self._attach_params = None
        self._extend_params = None
        self._merchant_id = None
        self._scene = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def attach_params(self):
        return self._attach_params

    @attach_params.setter
    def attach_params(self, value):
        self._attach_params = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.attach_params:
            if hasattr(self.attach_params, 'to_alipay_dict'):
                params['attach_params'] = self.attach_params.to_alipay_dict()
            else:
                params['attach_params'] = self.attach_params
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankEcnyTradeQrcodecreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'attach_params' in d:
            o.attach_params = d['attach_params']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsAutoUserMsgSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsAutoUserMsgSendResponse, self).__init__()
        self._can_retry = None

    @property
    def can_retry(self):
        return self._can_retry

    @can_retry.setter
    def can_retry(self, value):
        self._can_retry = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsAutoUserMsgSendResponse, self).parse_response_content(response_content)
        if 'can_retry' in response:
            self.can_retry = response['can_retry']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenOperationBizfeeAftechConsultModel(object):

    def __init__(self):
        self._app_name = None
        self._biz_no = None
        self._customer = None
        self._event_codes = None
        self._gmt_charge = None
        self._out_biz_no = None
        self._product_code = None
        self._properties = None
        self._tnt_inst_id = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def customer(self):
        return self._customer

    @customer.setter
    def customer(self, value):
        self._customer = value
    @property
    def event_codes(self):
        return self._event_codes

    @event_codes.setter
    def event_codes(self, value):
        self._event_codes = value
    @property
    def gmt_charge(self):
        return self._gmt_charge

    @gmt_charge.setter
    def gmt_charge(self, value):
        self._gmt_charge = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def properties(self):
        return self._properties

    @properties.setter
    def properties(self, value):
        self._properties = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.customer:
            if hasattr(self.customer, 'to_alipay_dict'):
                params['customer'] = self.customer.to_alipay_dict()
            else:
                params['customer'] = self.customer
        if self.event_codes:
            if hasattr(self.event_codes, 'to_alipay_dict'):
                params['event_codes'] = self.event_codes.to_alipay_dict()
            else:
                params['event_codes'] = self.event_codes
        if self.gmt_charge:
            if hasattr(self.gmt_charge, 'to_alipay_dict'):
                params['gmt_charge'] = self.gmt_charge.to_alipay_dict()
            else:
                params['gmt_charge'] = self.gmt_charge
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.properties:
            if hasattr(self.properties, 'to_alipay_dict'):
                params['properties'] = self.properties.to_alipay_dict()
            else:
                params['properties'] = self.properties
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenOperationBizfeeAftechConsultModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'customer' in d:
            o.customer = d['customer']
        if 'event_codes' in d:
            o.event_codes = d['event_codes']
        if 'gmt_charge' in d:
            o.gmt_charge = d['gmt_charge']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'properties' in d:
            o.properties = d['properties']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodItem(object):

    def __init__(self):
        self._available_city_list = None
        self._brand = None
        self._cate = None
        self._cate_cnt = None
        self._comment_cnt = None
        self._content = None
        self._current_price = None
        self._deposit_amount = None
        self._detail_pic_num = None
        self._detail_url = None
        self._ext_json = None
        self._fresh_degree = None
        self._front_end_category = None
        self._id = None
        self._mini_app_id = None
        self._origin_price = None
        self._pic_url_list = None
        self._promo_pic_url_list = None
        self._pub_time = None
        self._rating = None
        self._rental_date = None
        self._rental_free = None
        self._row_type = None
        self._self_pickup = None
        self._shipment_rate = None
        self._shipments = None
        self._shop_id = None
        self._shop_name = None
        self._spu_id = None
        self._status = None
        self._stock_num = None
        self._store_rating = None
        self._tags = None
        self._title = None

    @property
    def available_city_list(self):
        return self._available_city_list

    @available_city_list.setter
    def available_city_list(self, value):
        if isinstance(value, list):
            self._available_city_list = list()
            for i in value:
                self._available_city_list.append(i)
    @property
    def brand(self):
        return self._brand

    @brand.setter
    def brand(self, value):
        self._brand = value
    @property
    def cate(self):
        return self._cate

    @cate.setter
    def cate(self, value):
        self._cate = value
    @property
    def cate_cnt(self):
        return self._cate_cnt

    @cate_cnt.setter
    def cate_cnt(self, value):
        self._cate_cnt = value
    @property
    def comment_cnt(self):
        return self._comment_cnt

    @comment_cnt.setter
    def comment_cnt(self, value):
        self._comment_cnt = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def current_price(self):
        return self._current_price

    @current_price.setter
    def current_price(self, value):
        self._current_price = value
    @property
    def deposit_amount(self):
        return self._deposit_amount

    @deposit_amount.setter
    def deposit_amount(self, value):
        self._deposit_amount = value
    @property
    def detail_pic_num(self):
        return self._detail_pic_num

    @detail_pic_num.setter
    def detail_pic_num(self, value):
        self._detail_pic_num = value
    @property
    def detail_url(self):
        return self._detail_url

    @detail_url.setter
    def detail_url(self, value):
        self._detail_url = value
    @property
    def ext_json(self):
        return self._ext_json

    @ext_json.setter
    def ext_json(self, value):
        self._ext_json = value
    @property
    def fresh_degree(self):
        return self._fresh_degree

    @fresh_degree.setter
    def fresh_degree(self, value):
        self._fresh_degree = value
    @property
    def front_end_category(self):
        return self._front_end_category

    @front_end_category.setter
    def front_end_category(self, value):
        self._front_end_category = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def origin_price(self):
        return self._origin_price

    @origin_price.setter
    def origin_price(self, value):
        self._origin_price = value
    @property
    def pic_url_list(self):
        return self._pic_url_list

    @pic_url_list.setter
    def pic_url_list(self, value):
        if isinstance(value, list):
            self._pic_url_list = list()
            for i in value:
                self._pic_url_list.append(i)
    @property
    def promo_pic_url_list(self):
        return self._promo_pic_url_list

    @promo_pic_url_list.setter
    def promo_pic_url_list(self, value):
        if isinstance(value, list):
            self._promo_pic_url_list = list()
            for i in value:
                self._promo_pic_url_list.append(i)
    @property
    def pub_time(self):
        return self._pub_time

    @pub_time.setter
    def pub_time(self, value):
        self._pub_time = value
    @property
    def rating(self):
        return self._rating

    @rating.setter
    def rating(self, value):
        self._rating = value
    @property
    def rental_date(self):
        return self._rental_date

    @rental_date.setter
    def rental_date(self, value):
        self._rental_date = value
    @property
    def rental_free(self):
        return self._rental_free

    @rental_free.setter
    def rental_free(self, value):
        self._rental_free = value
    @property
    def row_type(self):
        return self._row_type

    @row_type.setter
    def row_type(self, value):
        self._row_type = value
    @property
    def self_pickup(self):
        return self._self_pickup

    @self_pickup.setter
    def self_pickup(self, value):
        self._self_pickup = value
    @property
    def shipment_rate(self):
        return self._shipment_rate

    @shipment_rate.setter
    def shipment_rate(self, value):
        self._shipment_rate = value
    @property
    def shipments(self):
        return self._shipments

    @shipments.setter
    def shipments(self, value):
        self._shipments = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def spu_id(self):
        return self._spu_id

    @spu_id.setter
    def spu_id(self, value):
        self._spu_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def stock_num(self):
        return self._stock_num

    @stock_num.setter
    def stock_num(self, value):
        self._stock_num = value
    @property
    def store_rating(self):
        return self._store_rating

    @store_rating.setter
    def store_rating(self, value):
        self._store_rating = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_city_list:
            if isinstance(self.available_city_list, list):
                for i in range(0, len(self.available_city_list)):
                    element = self.available_city_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_city_list[i] = element.to_alipay_dict()
            if hasattr(self.available_city_list, 'to_alipay_dict'):
                params['available_city_list'] = self.available_city_list.to_alipay_dict()
            else:
                params['available_city_list'] = self.available_city_list
        if self.brand:
            if hasattr(self.brand, 'to_alipay_dict'):
                params['brand'] = self.brand.to_alipay_dict()
            else:
                params['brand'] = self.brand
        if self.cate:
            if hasattr(self.cate, 'to_alipay_dict'):
                params['cate'] = self.cate.to_alipay_dict()
            else:
                params['cate'] = self.cate
        if self.cate_cnt:
            if hasattr(self.cate_cnt, 'to_alipay_dict'):
                params['cate_cnt'] = self.cate_cnt.to_alipay_dict()
            else:
                params['cate_cnt'] = self.cate_cnt
        if self.comment_cnt:
            if hasattr(self.comment_cnt, 'to_alipay_dict'):
                params['comment_cnt'] = self.comment_cnt.to_alipay_dict()
            else:
                params['comment_cnt'] = self.comment_cnt
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.current_price:
            if hasattr(self.current_price, 'to_alipay_dict'):
                params['current_price'] = self.current_price.to_alipay_dict()
            else:
                params['current_price'] = self.current_price
        if self.deposit_amount:
            if hasattr(self.deposit_amount, 'to_alipay_dict'):
                params['deposit_amount'] = self.deposit_amount.to_alipay_dict()
            else:
                params['deposit_amount'] = self.deposit_amount
        if self.detail_pic_num:
            if hasattr(self.detail_pic_num, 'to_alipay_dict'):
                params['detail_pic_num'] = self.detail_pic_num.to_alipay_dict()
            else:
                params['detail_pic_num'] = self.detail_pic_num
        if self.detail_url:
            if hasattr(self.detail_url, 'to_alipay_dict'):
                params['detail_url'] = self.detail_url.to_alipay_dict()
            else:
                params['detail_url'] = self.detail_url
        if self.ext_json:
            if hasattr(self.ext_json, 'to_alipay_dict'):
                params['ext_json'] = self.ext_json.to_alipay_dict()
            else:
                params['ext_json'] = self.ext_json
        if self.fresh_degree:
            if hasattr(self.fresh_degree, 'to_alipay_dict'):
                params['fresh_degree'] = self.fresh_degree.to_alipay_dict()
            else:
                params['fresh_degree'] = self.fresh_degree
        if self.front_end_category:
            if hasattr(self.front_end_category, 'to_alipay_dict'):
                params['front_end_category'] = self.front_end_category.to_alipay_dict()
            else:
                params['front_end_category'] = self.front_end_category
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.origin_price:
            if hasattr(self.origin_price, 'to_alipay_dict'):
                params['origin_price'] = self.origin_price.to_alipay_dict()
            else:
                params['origin_price'] = self.origin_price
        if self.pic_url_list:
            if isinstance(self.pic_url_list, list):
                for i in range(0, len(self.pic_url_list)):
                    element = self.pic_url_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pic_url_list[i] = element.to_alipay_dict()
            if hasattr(self.pic_url_list, 'to_alipay_dict'):
                params['pic_url_list'] = self.pic_url_list.to_alipay_dict()
            else:
                params['pic_url_list'] = self.pic_url_list
        if self.promo_pic_url_list:
            if isinstance(self.promo_pic_url_list, list):
                for i in range(0, len(self.promo_pic_url_list)):
                    element = self.promo_pic_url_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.promo_pic_url_list[i] = element.to_alipay_dict()
            if hasattr(self.promo_pic_url_list, 'to_alipay_dict'):
                params['promo_pic_url_list'] = self.promo_pic_url_list.to_alipay_dict()
            else:
                params['promo_pic_url_list'] = self.promo_pic_url_list
        if self.pub_time:
            if hasattr(self.pub_time, 'to_alipay_dict'):
                params['pub_time'] = self.pub_time.to_alipay_dict()
            else:
                params['pub_time'] = self.pub_time
        if self.rating:
            if hasattr(self.rating, 'to_alipay_dict'):
                params['rating'] = self.rating.to_alipay_dict()
            else:
                params['rating'] = self.rating
        if self.rental_date:
            if hasattr(self.rental_date, 'to_alipay_dict'):
                params['rental_date'] = self.rental_date.to_alipay_dict()
            else:
                params['rental_date'] = self.rental_date
        if self.rental_free:
            if hasattr(self.rental_free, 'to_alipay_dict'):
                params['rental_free'] = self.rental_free.to_alipay_dict()
            else:
                params['rental_free'] = self.rental_free
        if self.row_type:
            if hasattr(self.row_type, 'to_alipay_dict'):
                params['row_type'] = self.row_type.to_alipay_dict()
            else:
                params['row_type'] = self.row_type
        if self.self_pickup:
            if hasattr(self.self_pickup, 'to_alipay_dict'):
                params['self_pickup'] = self.self_pickup.to_alipay_dict()
            else:
                params['self_pickup'] = self.self_pickup
        if self.shipment_rate:
            if hasattr(self.shipment_rate, 'to_alipay_dict'):
                params['shipment_rate'] = self.shipment_rate.to_alipay_dict()
            else:
                params['shipment_rate'] = self.shipment_rate
        if self.shipments:
            if hasattr(self.shipments, 'to_alipay_dict'):
                params['shipments'] = self.shipments.to_alipay_dict()
            else:
                params['shipments'] = self.shipments
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.spu_id:
            if hasattr(self.spu_id, 'to_alipay_dict'):
                params['spu_id'] = self.spu_id.to_alipay_dict()
            else:
                params['spu_id'] = self.spu_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.stock_num:
            if hasattr(self.stock_num, 'to_alipay_dict'):
                params['stock_num'] = self.stock_num.to_alipay_dict()
            else:
                params['stock_num'] = self.stock_num
        if self.store_rating:
            if hasattr(self.store_rating, 'to_alipay_dict'):
                params['store_rating'] = self.store_rating.to_alipay_dict()
            else:
                params['store_rating'] = self.store_rating
        if self.tags:
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodItem()
        if 'available_city_list' in d:
            o.available_city_list = d['available_city_list']
        if 'brand' in d:
            o.brand = d['brand']
        if 'cate' in d:
            o.cate = d['cate']
        if 'cate_cnt' in d:
            o.cate_cnt = d['cate_cnt']
        if 'comment_cnt' in d:
            o.comment_cnt = d['comment_cnt']
        if 'content' in d:
            o.content = d['content']
        if 'current_price' in d:
            o.current_price = d['current_price']
        if 'deposit_amount' in d:
            o.deposit_amount = d['deposit_amount']
        if 'detail_pic_num' in d:
            o.detail_pic_num = d['detail_pic_num']
        if 'detail_url' in d:
            o.detail_url = d['detail_url']
        if 'ext_json' in d:
            o.ext_json = d['ext_json']
        if 'fresh_degree' in d:
            o.fresh_degree = d['fresh_degree']
        if 'front_end_category' in d:
            o.front_end_category = d['front_end_category']
        if 'id' in d:
            o.id = d['id']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'origin_price' in d:
            o.origin_price = d['origin_price']
        if 'pic_url_list' in d:
            o.pic_url_list = d['pic_url_list']
        if 'promo_pic_url_list' in d:
            o.promo_pic_url_list = d['promo_pic_url_list']
        if 'pub_time' in d:
            o.pub_time = d['pub_time']
        if 'rating' in d:
            o.rating = d['rating']
        if 'rental_date' in d:
            o.rental_date = d['rental_date']
        if 'rental_free' in d:
            o.rental_free = d['rental_free']
        if 'row_type' in d:
            o.row_type = d['row_type']
        if 'self_pickup' in d:
            o.self_pickup = d['self_pickup']
        if 'shipment_rate' in d:
            o.shipment_rate = d['shipment_rate']
        if 'shipments' in d:
            o.shipments = d['shipments']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'spu_id' in d:
            o.spu_id = d['spu_id']
        if 'status' in d:
            o.status = d['status']
        if 'stock_num' in d:
            o.stock_num = d['stock_num']
        if 'store_rating' in d:
            o.store_rating = d['store_rating']
        if 'tags' in d:
            o.tags = d['tags']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTransferPaymentDisburseResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTransferPaymentDisburseResponse, self).__init__()
        self._pass_through_info = None
        self._transaction_results = None

    @property
    def pass_through_info(self):
        return self._pass_through_info

    @pass_through_info.setter
    def pass_through_info(self, value):
        self._pass_through_info = value
    @property
    def transaction_results(self):
        return self._transaction_results

    @transaction_results.setter
    def transaction_results(self, value):
        self._transaction_results = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTransferPaymentDisburseResponse, self).parse_response_content(response_content)
        if 'pass_through_info' in response:
            self.pass_through_info = response['pass_through_info']
        if 'transaction_results' in response:
            self.transaction_results = response['transaction_results']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UserInformation(object):

    def __init__(self):
        self._mobile = None
        self._name = None

    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserInformation()
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PaymentApplyQueryOrder import PaymentApplyQueryOrder


class AlipayBossFncGfsettleprodInvoicebillQueryModel(object):

    def __init__(self):
        self._payment_apply_query_order = None

    @property
    def payment_apply_query_order(self):
        return self._payment_apply_query_order

    @payment_apply_query_order.setter
    def payment_apply_query_order(self, value):
        if isinstance(value, PaymentApplyQueryOrder):
            self._payment_apply_query_order = value
        else:
            self._payment_apply_query_order = PaymentApplyQueryOrder.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.payment_apply_query_order:
            if hasattr(self.payment_apply_query_order, 'to_alipay_dict'):
                params['payment_apply_query_order'] = self.payment_apply_query_order.to_alipay_dict()
            else:
                params['payment_apply_query_order'] = self.payment_apply_query_order
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodInvoicebillQueryModel()
        if 'payment_apply_query_order' in d:
            o.payment_apply_query_order = d['payment_apply_query_order']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiShopMallPageModifyModel(object):

    def __init__(self):
        self._mall_id = None
        self._mall_url = None
        self._out_biz_id = None

    @property
    def mall_id(self):
        return self._mall_id

    @mall_id.setter
    def mall_id(self, value):
        self._mall_id = value
    @property
    def mall_url(self):
        return self._mall_url

    @mall_url.setter
    def mall_url(self, value):
        self._mall_url = value
    @property
    def out_biz_id(self):
        return self._out_biz_id

    @out_biz_id.setter
    def out_biz_id(self, value):
        self._out_biz_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.mall_id:
            if hasattr(self.mall_id, 'to_alipay_dict'):
                params['mall_id'] = self.mall_id.to_alipay_dict()
            else:
                params['mall_id'] = self.mall_id
        if self.mall_url:
            if hasattr(self.mall_url, 'to_alipay_dict'):
                params['mall_url'] = self.mall_url.to_alipay_dict()
            else:
                params['mall_url'] = self.mall_url
        if self.out_biz_id:
            if hasattr(self.out_biz_id, 'to_alipay_dict'):
                params['out_biz_id'] = self.out_biz_id.to_alipay_dict()
            else:
                params['out_biz_id'] = self.out_biz_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiShopMallPageModifyModel()
        if 'mall_id' in d:
            o.mall_id = d['mall_id']
        if 'mall_url' in d:
            o.mall_url = d['mall_url']
        if 'out_biz_id' in d:
            o.out_biz_id = d['out_biz_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataBillFreezebalanceQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataBillFreezebalanceQueryResponse, self).__init__()
        self._freeze_amount = None

    @property
    def freeze_amount(self):
        return self._freeze_amount

    @freeze_amount.setter
    def freeze_amount(self, value):
        self._freeze_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataBillFreezebalanceQueryResponse, self).parse_response_content(response_content)
        if 'freeze_amount' in response:
            self.freeze_amount = response['freeze_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BankcardExtInfo(object):

    def __init__(self):
        self._account_type = None
        self._bank_code = None
        self._inst_branch_name = None
        self._inst_city = None
        self._inst_name = None
        self._inst_province = None

    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def bank_code(self):
        return self._bank_code

    @bank_code.setter
    def bank_code(self, value):
        self._bank_code = value
    @property
    def inst_branch_name(self):
        return self._inst_branch_name

    @inst_branch_name.setter
    def inst_branch_name(self, value):
        self._inst_branch_name = value
    @property
    def inst_city(self):
        return self._inst_city

    @inst_city.setter
    def inst_city(self, value):
        self._inst_city = value
    @property
    def inst_name(self):
        return self._inst_name

    @inst_name.setter
    def inst_name(self, value):
        self._inst_name = value
    @property
    def inst_province(self):
        return self._inst_province

    @inst_province.setter
    def inst_province(self, value):
        self._inst_province = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.bank_code:
            if hasattr(self.bank_code, 'to_alipay_dict'):
                params['bank_code'] = self.bank_code.to_alipay_dict()
            else:
                params['bank_code'] = self.bank_code
        if self.inst_branch_name:
            if hasattr(self.inst_branch_name, 'to_alipay_dict'):
                params['inst_branch_name'] = self.inst_branch_name.to_alipay_dict()
            else:
                params['inst_branch_name'] = self.inst_branch_name
        if self.inst_city:
            if hasattr(self.inst_city, 'to_alipay_dict'):
                params['inst_city'] = self.inst_city.to_alipay_dict()
            else:
                params['inst_city'] = self.inst_city
        if self.inst_name:
            if hasattr(self.inst_name, 'to_alipay_dict'):
                params['inst_name'] = self.inst_name.to_alipay_dict()
            else:
                params['inst_name'] = self.inst_name
        if self.inst_province:
            if hasattr(self.inst_province, 'to_alipay_dict'):
                params['inst_province'] = self.inst_province.to_alipay_dict()
            else:
                params['inst_province'] = self.inst_province
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BankcardExtInfo()
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'bank_code' in d:
            o.bank_code = d['bank_code']
        if 'inst_branch_name' in d:
            o.inst_branch_name = d['inst_branch_name']
        if 'inst_city' in d:
            o.inst_city = d['inst_city']
        if 'inst_name' in d:
            o.inst_name = d['inst_name']
        if 'inst_province' in d:
            o.inst_province = d['inst_province']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityDataAlibabaSecuritydataSendModel(object):

    def __init__(self):
        self._biz_content_value = None
        self._biz_id = None
        self._ingest_name = None
        self._main_target_type = None
        self._main_target_value = None
        self._open_id = None
        self._property = None
        self._property_second = None
        self._property_third = None
        self._risk_type = None
        self._scope = None
        self._source = None
        self._system_name = None
        self._table_name = None
        self._time = None
        self._use_scope = None
        self._user_id = None

    @property
    def biz_content_value(self):
        return self._biz_content_value

    @biz_content_value.setter
    def biz_content_value(self, value):
        self._biz_content_value = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def ingest_name(self):
        return self._ingest_name

    @ingest_name.setter
    def ingest_name(self, value):
        self._ingest_name = value
    @property
    def main_target_type(self):
        return self._main_target_type

    @main_target_type.setter
    def main_target_type(self, value):
        self._main_target_type = value
    @property
    def main_target_value(self):
        return self._main_target_value

    @main_target_value.setter
    def main_target_value(self, value):
        self._main_target_value = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def property(self):
        return self._property

    @property.setter
    def property(self, value):
        self._property = value
    @property
    def property_second(self):
        return self._property_second

    @property_second.setter
    def property_second(self, value):
        self._property_second = value
    @property
    def property_third(self):
        return self._property_third

    @property_third.setter
    def property_third(self, value):
        self._property_third = value
    @property
    def risk_type(self):
        return self._risk_type

    @risk_type.setter
    def risk_type(self, value):
        self._risk_type = value
    @property
    def scope(self):
        return self._scope

    @scope.setter
    def scope(self, value):
        self._scope = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def system_name(self):
        return self._system_name

    @system_name.setter
    def system_name(self, value):
        self._system_name = value
    @property
    def table_name(self):
        return self._table_name

    @table_name.setter
    def table_name(self, value):
        self._table_name = value
    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        self._time = value
    @property
    def use_scope(self):
        return self._use_scope

    @use_scope.setter
    def use_scope(self, value):
        self._use_scope = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_content_value:
            if hasattr(self.biz_content_value, 'to_alipay_dict'):
                params['biz_content_value'] = self.biz_content_value.to_alipay_dict()
            else:
                params['biz_content_value'] = self.biz_content_value
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.ingest_name:
            if hasattr(self.ingest_name, 'to_alipay_dict'):
                params['ingest_name'] = self.ingest_name.to_alipay_dict()
            else:
                params['ingest_name'] = self.ingest_name
        if self.main_target_type:
            if hasattr(self.main_target_type, 'to_alipay_dict'):
                params['main_target_type'] = self.main_target_type.to_alipay_dict()
            else:
                params['main_target_type'] = self.main_target_type
        if self.main_target_value:
            if hasattr(self.main_target_value, 'to_alipay_dict'):
                params['main_target_value'] = self.main_target_value.to_alipay_dict()
            else:
                params['main_target_value'] = self.main_target_value
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.property:
            if hasattr(self.property, 'to_alipay_dict'):
                params['property'] = self.property.to_alipay_dict()
            else:
                params['property'] = self.property
        if self.property_second:
            if hasattr(self.property_second, 'to_alipay_dict'):
                params['property_second'] = self.property_second.to_alipay_dict()
            else:
                params['property_second'] = self.property_second
        if self.property_third:
            if hasattr(self.property_third, 'to_alipay_dict'):
                params['property_third'] = self.property_third.to_alipay_dict()
            else:
                params['property_third'] = self.property_third
        if self.risk_type:
            if hasattr(self.risk_type, 'to_alipay_dict'):
                params['risk_type'] = self.risk_type.to_alipay_dict()
            else:
                params['risk_type'] = self.risk_type
        if self.scope:
            if hasattr(self.scope, 'to_alipay_dict'):
                params['scope'] = self.scope.to_alipay_dict()
            else:
                params['scope'] = self.scope
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.system_name:
            if hasattr(self.system_name, 'to_alipay_dict'):
                params['system_name'] = self.system_name.to_alipay_dict()
            else:
                params['system_name'] = self.system_name
        if self.table_name:
            if hasattr(self.table_name, 'to_alipay_dict'):
                params['table_name'] = self.table_name.to_alipay_dict()
            else:
                params['table_name'] = self.table_name
        if self.time:
            if hasattr(self.time, 'to_alipay_dict'):
                params['time'] = self.time.to_alipay_dict()
            else:
                params['time'] = self.time
        if self.use_scope:
            if hasattr(self.use_scope, 'to_alipay_dict'):
                params['use_scope'] = self.use_scope.to_alipay_dict()
            else:
                params['use_scope'] = self.use_scope
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityDataAlibabaSecuritydataSendModel()
        if 'biz_content_value' in d:
            o.biz_content_value = d['biz_content_value']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'ingest_name' in d:
            o.ingest_name = d['ingest_name']
        if 'main_target_type' in d:
            o.main_target_type = d['main_target_type']
        if 'main_target_value' in d:
            o.main_target_value = d['main_target_value']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'property' in d:
            o.property = d['property']
        if 'property_second' in d:
            o.property_second = d['property_second']
        if 'property_third' in d:
            o.property_third = d['property_third']
        if 'risk_type' in d:
            o.risk_type = d['risk_type']
        if 'scope' in d:
            o.scope = d['scope']
        if 'source' in d:
            o.source = d['source']
        if 'system_name' in d:
            o.system_name = d['system_name']
        if 'table_name' in d:
            o.table_name = d['table_name']
        if 'time' in d:
            o.time = d['time']
        if 'use_scope' in d:
            o.use_scope = d['use_scope']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RelationVO(object):

    def __init__(self):
        self._oppo_account_name = None
        self._oppo_child_id = None
        self._oppo_head_url = None
        self._oppo_nick_name = None
        self._oppo_real_name = None

    @property
    def oppo_account_name(self):
        return self._oppo_account_name

    @oppo_account_name.setter
    def oppo_account_name(self, value):
        self._oppo_account_name = value
    @property
    def oppo_child_id(self):
        return self._oppo_child_id

    @oppo_child_id.setter
    def oppo_child_id(self, value):
        self._oppo_child_id = value
    @property
    def oppo_head_url(self):
        return self._oppo_head_url

    @oppo_head_url.setter
    def oppo_head_url(self, value):
        self._oppo_head_url = value
    @property
    def oppo_nick_name(self):
        return self._oppo_nick_name

    @oppo_nick_name.setter
    def oppo_nick_name(self, value):
        self._oppo_nick_name = value
    @property
    def oppo_real_name(self):
        return self._oppo_real_name

    @oppo_real_name.setter
    def oppo_real_name(self, value):
        self._oppo_real_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.oppo_account_name:
            if hasattr(self.oppo_account_name, 'to_alipay_dict'):
                params['oppo_account_name'] = self.oppo_account_name.to_alipay_dict()
            else:
                params['oppo_account_name'] = self.oppo_account_name
        if self.oppo_child_id:
            if hasattr(self.oppo_child_id, 'to_alipay_dict'):
                params['oppo_child_id'] = self.oppo_child_id.to_alipay_dict()
            else:
                params['oppo_child_id'] = self.oppo_child_id
        if self.oppo_head_url:
            if hasattr(self.oppo_head_url, 'to_alipay_dict'):
                params['oppo_head_url'] = self.oppo_head_url.to_alipay_dict()
            else:
                params['oppo_head_url'] = self.oppo_head_url
        if self.oppo_nick_name:
            if hasattr(self.oppo_nick_name, 'to_alipay_dict'):
                params['oppo_nick_name'] = self.oppo_nick_name.to_alipay_dict()
            else:
                params['oppo_nick_name'] = self.oppo_nick_name
        if self.oppo_real_name:
            if hasattr(self.oppo_real_name, 'to_alipay_dict'):
                params['oppo_real_name'] = self.oppo_real_name.to_alipay_dict()
            else:
                params['oppo_real_name'] = self.oppo_real_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RelationVO()
        if 'oppo_account_name' in d:
            o.oppo_account_name = d['oppo_account_name']
        if 'oppo_child_id' in d:
            o.oppo_child_id = d['oppo_child_id']
        if 'oppo_head_url' in d:
            o.oppo_head_url = d['oppo_head_url']
        if 'oppo_nick_name' in d:
            o.oppo_nick_name = d['oppo_nick_name']
        if 'oppo_real_name' in d:
            o.oppo_real_name = d['oppo_real_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ApeRecContext(object):

    def __init__(self):
        self._black_index_list = None
        self._cate = None
        self._city_code = None
        self._client_env = None
        self._current_item_id = None
        self._device_id = None
        self._landing_item_list = None
        self._latitude = None
        self._lbs_distance = None
        self._longitude = None
        self._other_index_list = None
        self._select_id_list = None
        self._tags = None

    @property
    def black_index_list(self):
        return self._black_index_list

    @black_index_list.setter
    def black_index_list(self, value):
        if isinstance(value, list):
            self._black_index_list = list()
            for i in value:
                self._black_index_list.append(i)
    @property
    def cate(self):
        return self._cate

    @cate.setter
    def cate(self, value):
        if isinstance(value, list):
            self._cate = list()
            for i in value:
                self._cate.append(i)
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def client_env(self):
        return self._client_env

    @client_env.setter
    def client_env(self, value):
        self._client_env = value
    @property
    def current_item_id(self):
        return self._current_item_id

    @current_item_id.setter
    def current_item_id(self, value):
        self._current_item_id = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def landing_item_list(self):
        return self._landing_item_list

    @landing_item_list.setter
    def landing_item_list(self, value):
        if isinstance(value, list):
            self._landing_item_list = list()
            for i in value:
                self._landing_item_list.append(i)
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def lbs_distance(self):
        return self._lbs_distance

    @lbs_distance.setter
    def lbs_distance(self, value):
        self._lbs_distance = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def other_index_list(self):
        return self._other_index_list

    @other_index_list.setter
    def other_index_list(self, value):
        if isinstance(value, list):
            self._other_index_list = list()
            for i in value:
                self._other_index_list.append(i)
    @property
    def select_id_list(self):
        return self._select_id_list

    @select_id_list.setter
    def select_id_list(self, value):
        if isinstance(value, list):
            self._select_id_list = list()
            for i in value:
                self._select_id_list.append(i)
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        if isinstance(value, list):
            self._tags = list()
            for i in value:
                self._tags.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.black_index_list:
            if isinstance(self.black_index_list, list):
                for i in range(0, len(self.black_index_list)):
                    element = self.black_index_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.black_index_list[i] = element.to_alipay_dict()
            if hasattr(self.black_index_list, 'to_alipay_dict'):
                params['black_index_list'] = self.black_index_list.to_alipay_dict()
            else:
                params['black_index_list'] = self.black_index_list
        if self.cate:
            if isinstance(self.cate, list):
                for i in range(0, len(self.cate)):
                    element = self.cate[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cate[i] = element.to_alipay_dict()
            if hasattr(self.cate, 'to_alipay_dict'):
                params['cate'] = self.cate.to_alipay_dict()
            else:
                params['cate'] = self.cate
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.client_env:
            if hasattr(self.client_env, 'to_alipay_dict'):
                params['client_env'] = self.client_env.to_alipay_dict()
            else:
                params['client_env'] = self.client_env
        if self.current_item_id:
            if hasattr(self.current_item_id, 'to_alipay_dict'):
                params['current_item_id'] = self.current_item_id.to_alipay_dict()
            else:
                params['current_item_id'] = self.current_item_id
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.landing_item_list:
            if isinstance(self.landing_item_list, list):
                for i in range(0, len(self.landing_item_list)):
                    element = self.landing_item_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.landing_item_list[i] = element.to_alipay_dict()
            if hasattr(self.landing_item_list, 'to_alipay_dict'):
                params['landing_item_list'] = self.landing_item_list.to_alipay_dict()
            else:
                params['landing_item_list'] = self.landing_item_list
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.lbs_distance:
            if hasattr(self.lbs_distance, 'to_alipay_dict'):
                params['lbs_distance'] = self.lbs_distance.to_alipay_dict()
            else:
                params['lbs_distance'] = self.lbs_distance
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.other_index_list:
            if isinstance(self.other_index_list, list):
                for i in range(0, len(self.other_index_list)):
                    element = self.other_index_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.other_index_list[i] = element.to_alipay_dict()
            if hasattr(self.other_index_list, 'to_alipay_dict'):
                params['other_index_list'] = self.other_index_list.to_alipay_dict()
            else:
                params['other_index_list'] = self.other_index_list
        if self.select_id_list:
            if isinstance(self.select_id_list, list):
                for i in range(0, len(self.select_id_list)):
                    element = self.select_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.select_id_list[i] = element.to_alipay_dict()
            if hasattr(self.select_id_list, 'to_alipay_dict'):
                params['select_id_list'] = self.select_id_list.to_alipay_dict()
            else:
                params['select_id_list'] = self.select_id_list
        if self.tags:
            if isinstance(self.tags, list):
                for i in range(0, len(self.tags)):
                    element = self.tags[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tags[i] = element.to_alipay_dict()
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApeRecContext()
        if 'black_index_list' in d:
            o.black_index_list = d['black_index_list']
        if 'cate' in d:
            o.cate = d['cate']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'client_env' in d:
            o.client_env = d['client_env']
        if 'current_item_id' in d:
            o.current_item_id = d['current_item_id']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'landing_item_list' in d:
            o.landing_item_list = d['landing_item_list']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'lbs_distance' in d:
            o.lbs_distance = d['lbs_distance']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'other_index_list' in d:
            o.other_index_list = d['other_index_list']
        if 'select_id_list' in d:
            o.select_id_list = d['select_id_list']
        if 'tags' in d:
            o.tags = d['tags']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PassAccountDTO import PassAccountDTO


class AnttechOceanbasePassaccountBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechOceanbasePassaccountBatchqueryResponse, self).__init__()
        self._pass_accounts = None

    @property
    def pass_accounts(self):
        return self._pass_accounts

    @pass_accounts.setter
    def pass_accounts(self, value):
        if isinstance(value, list):
            self._pass_accounts = list()
            for i in value:
                if isinstance(i, PassAccountDTO):
                    self._pass_accounts.append(i)
                else:
                    self._pass_accounts.append(PassAccountDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AnttechOceanbasePassaccountBatchqueryResponse, self).parse_response_content(response_content)
        if 'pass_accounts' in response:
            self.pass_accounts = response['pass_accounts']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EnvironmentalDTO(object):

    def __init__(self):
        self._energy_amount = None
        self._environmental = None
        self._failure_code = None
        self._failure_reason = None
        self._status = None

    @property
    def energy_amount(self):
        return self._energy_amount

    @energy_amount.setter
    def energy_amount(self, value):
        self._energy_amount = value
    @property
    def environmental(self):
        return self._environmental

    @environmental.setter
    def environmental(self, value):
        self._environmental = value
    @property
    def failure_code(self):
        return self._failure_code

    @failure_code.setter
    def failure_code(self, value):
        self._failure_code = value
    @property
    def failure_reason(self):
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, value):
        self._failure_reason = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.energy_amount:
            if hasattr(self.energy_amount, 'to_alipay_dict'):
                params['energy_amount'] = self.energy_amount.to_alipay_dict()
            else:
                params['energy_amount'] = self.energy_amount
        if self.environmental:
            if hasattr(self.environmental, 'to_alipay_dict'):
                params['environmental'] = self.environmental.to_alipay_dict()
            else:
                params['environmental'] = self.environmental
        if self.failure_code:
            if hasattr(self.failure_code, 'to_alipay_dict'):
                params['failure_code'] = self.failure_code.to_alipay_dict()
            else:
                params['failure_code'] = self.failure_code
        if self.failure_reason:
            if hasattr(self.failure_reason, 'to_alipay_dict'):
                params['failure_reason'] = self.failure_reason.to_alipay_dict()
            else:
                params['failure_reason'] = self.failure_reason
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EnvironmentalDTO()
        if 'energy_amount' in d:
            o.energy_amount = d['energy_amount']
        if 'environmental' in d:
            o.environmental = d['environmental']
        if 'failure_code' in d:
            o.failure_code = d['failure_code']
        if 'failure_reason' in d:
            o.failure_reason = d['failure_reason']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MemberCardTemplateConfig import MemberCardTemplateConfig
from alipay.aop.api.domain.MemberCardPayEffectiveRule import MemberCardPayEffectiveRule
from alipay.aop.api.domain.MemberCardPrepaidPromotionPlanInfo import MemberCardPrepaidPromotionPlanInfo


class AntMerchantExpandMembercardConfigQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandMembercardConfigQueryResponse, self).__init__()
        self._card_template_config = None
        self._member_product_id = None
        self._pay_effective_rule = None
        self._prepaid_promotion_plans = None

    @property
    def card_template_config(self):
        return self._card_template_config

    @card_template_config.setter
    def card_template_config(self, value):
        if isinstance(value, MemberCardTemplateConfig):
            self._card_template_config = value
        else:
            self._card_template_config = MemberCardTemplateConfig.from_alipay_dict(value)
    @property
    def member_product_id(self):
        return self._member_product_id

    @member_product_id.setter
    def member_product_id(self, value):
        self._member_product_id = value
    @property
    def pay_effective_rule(self):
        return self._pay_effective_rule

    @pay_effective_rule.setter
    def pay_effective_rule(self, value):
        if isinstance(value, MemberCardPayEffectiveRule):
            self._pay_effective_rule = value
        else:
            self._pay_effective_rule = MemberCardPayEffectiveRule.from_alipay_dict(value)
    @property
    def prepaid_promotion_plans(self):
        return self._prepaid_promotion_plans

    @prepaid_promotion_plans.setter
    def prepaid_promotion_plans(self, value):
        if isinstance(value, list):
            self._prepaid_promotion_plans = list()
            for i in value:
                if isinstance(i, MemberCardPrepaidPromotionPlanInfo):
                    self._prepaid_promotion_plans.append(i)
                else:
                    self._prepaid_promotion_plans.append(MemberCardPrepaidPromotionPlanInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandMembercardConfigQueryResponse, self).parse_response_content(response_content)
        if 'card_template_config' in response:
            self.card_template_config = response['card_template_config']
        if 'member_product_id' in response:
            self.member_product_id = response['member_product_id']
        if 'pay_effective_rule' in response:
            self.pay_effective_rule = response['pay_effective_rule']
        if 'prepaid_promotion_plans' in response:
            self.prepaid_promotion_plans = response['prepaid_promotion_plans']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LogisticsCompanyDTO import LogisticsCompanyDTO


class AlipayOpenInstantdeliveryLogisticsBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenInstantdeliveryLogisticsBatchqueryResponse, self).__init__()
        self._logistics_companys = None

    @property
    def logistics_companys(self):
        return self._logistics_companys

    @logistics_companys.setter
    def logistics_companys(self, value):
        if isinstance(value, list):
            self._logistics_companys = list()
            for i in value:
                if isinstance(i, LogisticsCompanyDTO):
                    self._logistics_companys.append(i)
                else:
                    self._logistics_companys.append(LogisticsCompanyDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenInstantdeliveryLogisticsBatchqueryResponse, self).parse_response_content(response_content)
        if 'logistics_companys' in response:
            self.logistics_companys = response['logistics_companys']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsOpenAttachmentDTO(object):

    def __init__(self):
        self._afts_file_id = None
        self._biz_data = None
        self._description = None
        self._file_type = None
        self._name = None
        self._path = None
        self._size = None
        self._type = None

    @property
    def afts_file_id(self):
        return self._afts_file_id

    @afts_file_id.setter
    def afts_file_id(self, value):
        self._afts_file_id = value
    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, value):
        self._path = value
    @property
    def size(self):
        return self._size

    @size.setter
    def size(self, value):
        self._size = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.afts_file_id:
            if hasattr(self.afts_file_id, 'to_alipay_dict'):
                params['afts_file_id'] = self.afts_file_id.to_alipay_dict()
            else:
                params['afts_file_id'] = self.afts_file_id
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.path:
            if hasattr(self.path, 'to_alipay_dict'):
                params['path'] = self.path.to_alipay_dict()
            else:
                params['path'] = self.path
        if self.size:
            if hasattr(self.size, 'to_alipay_dict'):
                params['size'] = self.size.to_alipay_dict()
            else:
                params['size'] = self.size
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsOpenAttachmentDTO()
        if 'afts_file_id' in d:
            o.afts_file_id = d['afts_file_id']
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'description' in d:
            o.description = d['description']
        if 'file_type' in d:
            o.file_type = d['file_type']
        if 'name' in d:
            o.name = d['name']
        if 'path' in d:
            o.path = d['path']
        if 'size' in d:
            o.size = d['size']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class HuanxuUserHhhhhDeleteResponse(AlipayResponse):

    def __init__(self):
        super(HuanxuUserHhhhhDeleteResponse, self).__init__()
        self._aa = None
        self._app_name = None
        self._mini_app_id = None
        self._name = None

    @property
    def aa(self):
        return self._aa

    @aa.setter
    def aa(self, value):
        self._aa = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value

    def parse_response_content(self, response_content):
        response = super(HuanxuUserHhhhhDeleteResponse, self).parse_response_content(response_content)
        if 'aa' in response:
            self.aa = response['aa']
        if 'app_name' in response:
            self.app_name = response['app_name']
        if 'mini_app_id' in response:
            self.mini_app_id = response['mini_app_id']
        if 'name' in response:
            self.name = response['name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserInviteOfflinedetailQueryModel(object):

    def __init__(self):
        self._page = None
        self._page_size = None
        self._partner_id = None
        self._pid = None
        self._report_date = None
        self._task_id = None

    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def report_date(self):
        return self._report_date

    @report_date.setter
    def report_date(self, value):
        self._report_date = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.page:
            if hasattr(self.page, 'to_alipay_dict'):
                params['page'] = self.page.to_alipay_dict()
            else:
                params['page'] = self.page
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.report_date:
            if hasattr(self.report_date, 'to_alipay_dict'):
                params['report_date'] = self.report_date.to_alipay_dict()
            else:
                params['report_date'] = self.report_date
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserInviteOfflinedetailQueryModel()
        if 'page' in d:
            o.page = d['page']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pid' in d:
            o.pid = d['pid']
        if 'report_date' in d:
            o.report_date = d['report_date']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankPaymentTradeBusinessOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankPaymentTradeBusinessOrderQueryResponse, self).__init__()
        self._biz_scene = None
        self._currency_value = None
        self._order_no = None
        self._order_status = None
        self._out_trade_no = None
        self._pay_amt = None
        self._product_code = None
        self._refund_amt = None
        self._retry = None
        self._settle_amt = None
        self._trade_amt = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def currency_value(self):
        return self._currency_value

    @currency_value.setter
    def currency_value(self, value):
        self._currency_value = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def pay_amt(self):
        return self._pay_amt

    @pay_amt.setter
    def pay_amt(self, value):
        self._pay_amt = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def refund_amt(self):
        return self._refund_amt

    @refund_amt.setter
    def refund_amt(self, value):
        self._refund_amt = value
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value
    @property
    def settle_amt(self):
        return self._settle_amt

    @settle_amt.setter
    def settle_amt(self, value):
        self._settle_amt = value
    @property
    def trade_amt(self):
        return self._trade_amt

    @trade_amt.setter
    def trade_amt(self, value):
        self._trade_amt = value

    def parse_response_content(self, response_content):
        response = super(MybankPaymentTradeBusinessOrderQueryResponse, self).parse_response_content(response_content)
        if 'biz_scene' in response:
            self.biz_scene = response['biz_scene']
        if 'currency_value' in response:
            self.currency_value = response['currency_value']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'pay_amt' in response:
            self.pay_amt = response['pay_amt']
        if 'product_code' in response:
            self.product_code = response['product_code']
        if 'refund_amt' in response:
            self.refund_amt = response['refund_amt']
        if 'retry' in response:
            self.retry = response['retry']
        if 'settle_amt' in response:
            self.settle_amt = response['settle_amt']
        if 'trade_amt' in response:
            self.trade_amt = response['trade_amt']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditSupplychainFactoringSelleradmitQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSupplychainFactoringSelleradmitQueryResponse, self).__init__()
        self._exsit = None
        self._refuse_code = None
        self._refuse_msg = None
        self._refused = None
        self._white = None

    @property
    def exsit(self):
        return self._exsit

    @exsit.setter
    def exsit(self, value):
        self._exsit = value
    @property
    def refuse_code(self):
        return self._refuse_code

    @refuse_code.setter
    def refuse_code(self, value):
        self._refuse_code = value
    @property
    def refuse_msg(self):
        return self._refuse_msg

    @refuse_msg.setter
    def refuse_msg(self, value):
        self._refuse_msg = value
    @property
    def refused(self):
        return self._refused

    @refused.setter
    def refused(self, value):
        self._refused = value
    @property
    def white(self):
        return self._white

    @white.setter
    def white(self, value):
        self._white = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSupplychainFactoringSelleradmitQueryResponse, self).parse_response_content(response_content)
        if 'exsit' in response:
            self.exsit = response['exsit']
        if 'refuse_code' in response:
            self.refuse_code = response['refuse_code']
        if 'refuse_msg' in response:
            self.refuse_msg = response['refuse_msg']
        if 'refused' in response:
            self.refused = response['refused']
        if 'white' in response:
            self.white = response['white']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantQipanCrowdQueryModel(object):

    def __init__(self):
        self._crowd_code = None
        self._external_crowd_code = None

    @property
    def crowd_code(self):
        return self._crowd_code

    @crowd_code.setter
    def crowd_code(self, value):
        self._crowd_code = value
    @property
    def external_crowd_code(self):
        return self._external_crowd_code

    @external_crowd_code.setter
    def external_crowd_code(self, value):
        self._external_crowd_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.crowd_code:
            if hasattr(self.crowd_code, 'to_alipay_dict'):
                params['crowd_code'] = self.crowd_code.to_alipay_dict()
            else:
                params['crowd_code'] = self.crowd_code
        if self.external_crowd_code:
            if hasattr(self.external_crowd_code, 'to_alipay_dict'):
                params['external_crowd_code'] = self.external_crowd_code.to_alipay_dict()
            else:
                params['external_crowd_code'] = self.external_crowd_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantQipanCrowdQueryModel()
        if 'crowd_code' in d:
            o.crowd_code = d['crowd_code']
        if 'external_crowd_code' in d:
            o.external_crowd_code = d['external_crowd_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechMorseMarketingRtaCallbackModel(object):

    def __init__(self):
        self._campaign_id = None
        self._discount_amt = None
        self._extend_params = None
        self._mobile_sha_256 = None
        self._out_biz_no = None
        self._payment_amt = None
        self._resource_id = None
        self._trade_date = None
        self._trade_no = None
        self._trade_total_amt = None
        self._trade_type = None

    @property
    def campaign_id(self):
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, value):
        self._campaign_id = value
    @property
    def discount_amt(self):
        return self._discount_amt

    @discount_amt.setter
    def discount_amt(self, value):
        self._discount_amt = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def mobile_sha_256(self):
        return self._mobile_sha_256

    @mobile_sha_256.setter
    def mobile_sha_256(self, value):
        self._mobile_sha_256 = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def payment_amt(self):
        return self._payment_amt

    @payment_amt.setter
    def payment_amt(self, value):
        self._payment_amt = value
    @property
    def resource_id(self):
        return self._resource_id

    @resource_id.setter
    def resource_id(self, value):
        self._resource_id = value
    @property
    def trade_date(self):
        return self._trade_date

    @trade_date.setter
    def trade_date(self, value):
        self._trade_date = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_total_amt(self):
        return self._trade_total_amt

    @trade_total_amt.setter
    def trade_total_amt(self, value):
        self._trade_total_amt = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.campaign_id:
            if hasattr(self.campaign_id, 'to_alipay_dict'):
                params['campaign_id'] = self.campaign_id.to_alipay_dict()
            else:
                params['campaign_id'] = self.campaign_id
        if self.discount_amt:
            if hasattr(self.discount_amt, 'to_alipay_dict'):
                params['discount_amt'] = self.discount_amt.to_alipay_dict()
            else:
                params['discount_amt'] = self.discount_amt
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.mobile_sha_256:
            if hasattr(self.mobile_sha_256, 'to_alipay_dict'):
                params['mobile_sha_256'] = self.mobile_sha_256.to_alipay_dict()
            else:
                params['mobile_sha_256'] = self.mobile_sha_256
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.payment_amt:
            if hasattr(self.payment_amt, 'to_alipay_dict'):
                params['payment_amt'] = self.payment_amt.to_alipay_dict()
            else:
                params['payment_amt'] = self.payment_amt
        if self.resource_id:
            if hasattr(self.resource_id, 'to_alipay_dict'):
                params['resource_id'] = self.resource_id.to_alipay_dict()
            else:
                params['resource_id'] = self.resource_id
        if self.trade_date:
            if hasattr(self.trade_date, 'to_alipay_dict'):
                params['trade_date'] = self.trade_date.to_alipay_dict()
            else:
                params['trade_date'] = self.trade_date
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_total_amt:
            if hasattr(self.trade_total_amt, 'to_alipay_dict'):
                params['trade_total_amt'] = self.trade_total_amt.to_alipay_dict()
            else:
                params['trade_total_amt'] = self.trade_total_amt
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechMorseMarketingRtaCallbackModel()
        if 'campaign_id' in d:
            o.campaign_id = d['campaign_id']
        if 'discount_amt' in d:
            o.discount_amt = d['discount_amt']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'mobile_sha_256' in d:
            o.mobile_sha_256 = d['mobile_sha_256']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'payment_amt' in d:
            o.payment_amt = d['payment_amt']
        if 'resource_id' in d:
            o.resource_id = d['resource_id']
        if 'trade_date' in d:
            o.trade_date = d['trade_date']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_total_amt' in d:
            o.trade_total_amt = d['trade_total_amt']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FenceEvent import FenceEvent


class AlipayCommerceIotDeviceGeofenceQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotDeviceGeofenceQueryResponse, self).__init__()
        self._bind_device = None
        self._fence_events = None

    @property
    def bind_device(self):
        return self._bind_device

    @bind_device.setter
    def bind_device(self, value):
        if isinstance(value, list):
            self._bind_device = list()
            for i in value:
                self._bind_device.append(i)
    @property
    def fence_events(self):
        return self._fence_events

    @fence_events.setter
    def fence_events(self, value):
        if isinstance(value, list):
            self._fence_events = list()
            for i in value:
                if isinstance(i, FenceEvent):
                    self._fence_events.append(i)
                else:
                    self._fence_events.append(FenceEvent.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotDeviceGeofenceQueryResponse, self).parse_response_content(response_content)
        if 'bind_device' in response:
            self.bind_device = response['bind_device']
        if 'fence_events' in response:
            self.fence_events = response['fence_events']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityBenefit(object):

    def __init__(self):
        self._benefit_rule = None
        self._out_benefit_id = None
        self._priority = None
        self._status = None

    @property
    def benefit_rule(self):
        return self._benefit_rule

    @benefit_rule.setter
    def benefit_rule(self, value):
        self._benefit_rule = value
    @property
    def out_benefit_id(self):
        return self._out_benefit_id

    @out_benefit_id.setter
    def out_benefit_id(self, value):
        self._out_benefit_id = value
    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        self._priority = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_rule:
            if hasattr(self.benefit_rule, 'to_alipay_dict'):
                params['benefit_rule'] = self.benefit_rule.to_alipay_dict()
            else:
                params['benefit_rule'] = self.benefit_rule
        if self.out_benefit_id:
            if hasattr(self.out_benefit_id, 'to_alipay_dict'):
                params['out_benefit_id'] = self.out_benefit_id.to_alipay_dict()
            else:
                params['out_benefit_id'] = self.out_benefit_id
        if self.priority:
            if hasattr(self.priority, 'to_alipay_dict'):
                params['priority'] = self.priority.to_alipay_dict()
            else:
                params['priority'] = self.priority
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityBenefit()
        if 'benefit_rule' in d:
            o.benefit_rule = d['benefit_rule']
        if 'out_benefit_id' in d:
            o.out_benefit_id = d['out_benefit_id']
        if 'priority' in d:
            o.priority = d['priority']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCustomerJobworthAuthenticationQueryModel(object):

    def __init__(self):
        self._cert_no = None
        self._cert_type = None
        self._conn_key = None
        self._identity_type = None
        self._once_token = None
        self._open_id = None
        self._query_type = None
        self._service_id = None
        self._user_id = None

    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def conn_key(self):
        return self._conn_key

    @conn_key.setter
    def conn_key(self, value):
        self._conn_key = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value
    @property
    def once_token(self):
        return self._once_token

    @once_token.setter
    def once_token(self, value):
        self._once_token = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def query_type(self):
        return self._query_type

    @query_type.setter
    def query_type(self, value):
        self._query_type = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.conn_key:
            if hasattr(self.conn_key, 'to_alipay_dict'):
                params['conn_key'] = self.conn_key.to_alipay_dict()
            else:
                params['conn_key'] = self.conn_key
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        if self.once_token:
            if hasattr(self.once_token, 'to_alipay_dict'):
                params['once_token'] = self.once_token.to_alipay_dict()
            else:
                params['once_token'] = self.once_token
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.query_type:
            if hasattr(self.query_type, 'to_alipay_dict'):
                params['query_type'] = self.query_type.to_alipay_dict()
            else:
                params['query_type'] = self.query_type
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCustomerJobworthAuthenticationQueryModel()
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'conn_key' in d:
            o.conn_key = d['conn_key']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        if 'once_token' in d:
            o.once_token = d['once_token']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'query_type' in d:
            o.query_type = d['query_type']
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpMinitipsdeliveryQueryModel(object):

    def __init__(self):
        self._hhh = None
        self._xx = None
        self._xx_open_id = None

    @property
    def hhh(self):
        return self._hhh

    @hhh.setter
    def hhh(self, value):
        self._hhh = value
    @property
    def xx(self):
        return self._xx

    @xx.setter
    def xx(self, value):
        self._xx = value
    @property
    def xx_open_id(self):
        return self._xx_open_id

    @xx_open_id.setter
    def xx_open_id(self, value):
        self._xx_open_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.hhh:
            if hasattr(self.hhh, 'to_alipay_dict'):
                params['hhh'] = self.hhh.to_alipay_dict()
            else:
                params['hhh'] = self.hhh
        if self.xx:
            if hasattr(self.xx, 'to_alipay_dict'):
                params['xx'] = self.xx.to_alipay_dict()
            else:
                params['xx'] = self.xx
        if self.xx_open_id:
            if hasattr(self.xx_open_id, 'to_alipay_dict'):
                params['xx_open_id'] = self.xx_open_id.to_alipay_dict()
            else:
                params['xx_open_id'] = self.xx_open_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpMinitipsdeliveryQueryModel()
        if 'hhh' in d:
            o.hhh = d['hhh']
        if 'xx' in d:
            o.xx = d['xx']
        if 'xx_open_id' in d:
            o.xx_open_id = d['xx_open_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ClaimAdvancePaymentDTO(object):

    def __init__(self):
        self._claim_no = None
        self._claim_report_no = None
        self._in_account_name = None
        self._in_account_no = None
        self._in_account_type = None
        self._out_account_name = None
        self._out_account_no = None
        self._out_account_type = None
        self._pay_bill_no = None
        self._pay_channel = None
        self._pay_fee = None
        self._pay_order_no = None
        self._pay_out_biz_no = None
        self._pay_time = None
        self._policy_no = None

    @property
    def claim_no(self):
        return self._claim_no

    @claim_no.setter
    def claim_no(self, value):
        self._claim_no = value
    @property
    def claim_report_no(self):
        return self._claim_report_no

    @claim_report_no.setter
    def claim_report_no(self, value):
        self._claim_report_no = value
    @property
    def in_account_name(self):
        return self._in_account_name

    @in_account_name.setter
    def in_account_name(self, value):
        self._in_account_name = value
    @property
    def in_account_no(self):
        return self._in_account_no

    @in_account_no.setter
    def in_account_no(self, value):
        self._in_account_no = value
    @property
    def in_account_type(self):
        return self._in_account_type

    @in_account_type.setter
    def in_account_type(self, value):
        self._in_account_type = value
    @property
    def out_account_name(self):
        return self._out_account_name

    @out_account_name.setter
    def out_account_name(self, value):
        self._out_account_name = value
    @property
    def out_account_no(self):
        return self._out_account_no

    @out_account_no.setter
    def out_account_no(self, value):
        self._out_account_no = value
    @property
    def out_account_type(self):
        return self._out_account_type

    @out_account_type.setter
    def out_account_type(self, value):
        self._out_account_type = value
    @property
    def pay_bill_no(self):
        return self._pay_bill_no

    @pay_bill_no.setter
    def pay_bill_no(self, value):
        self._pay_bill_no = value
    @property
    def pay_channel(self):
        return self._pay_channel

    @pay_channel.setter
    def pay_channel(self, value):
        self._pay_channel = value
    @property
    def pay_fee(self):
        return self._pay_fee

    @pay_fee.setter
    def pay_fee(self, value):
        self._pay_fee = value
    @property
    def pay_order_no(self):
        return self._pay_order_no

    @pay_order_no.setter
    def pay_order_no(self, value):
        self._pay_order_no = value
    @property
    def pay_out_biz_no(self):
        return self._pay_out_biz_no

    @pay_out_biz_no.setter
    def pay_out_biz_no(self, value):
        self._pay_out_biz_no = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.claim_no:
            if hasattr(self.claim_no, 'to_alipay_dict'):
                params['claim_no'] = self.claim_no.to_alipay_dict()
            else:
                params['claim_no'] = self.claim_no
        if self.claim_report_no:
            if hasattr(self.claim_report_no, 'to_alipay_dict'):
                params['claim_report_no'] = self.claim_report_no.to_alipay_dict()
            else:
                params['claim_report_no'] = self.claim_report_no
        if self.in_account_name:
            if hasattr(self.in_account_name, 'to_alipay_dict'):
                params['in_account_name'] = self.in_account_name.to_alipay_dict()
            else:
                params['in_account_name'] = self.in_account_name
        if self.in_account_no:
            if hasattr(self.in_account_no, 'to_alipay_dict'):
                params['in_account_no'] = self.in_account_no.to_alipay_dict()
            else:
                params['in_account_no'] = self.in_account_no
        if self.in_account_type:
            if hasattr(self.in_account_type, 'to_alipay_dict'):
                params['in_account_type'] = self.in_account_type.to_alipay_dict()
            else:
                params['in_account_type'] = self.in_account_type
        if self.out_account_name:
            if hasattr(self.out_account_name, 'to_alipay_dict'):
                params['out_account_name'] = self.out_account_name.to_alipay_dict()
            else:
                params['out_account_name'] = self.out_account_name
        if self.out_account_no:
            if hasattr(self.out_account_no, 'to_alipay_dict'):
                params['out_account_no'] = self.out_account_no.to_alipay_dict()
            else:
                params['out_account_no'] = self.out_account_no
        if self.out_account_type:
            if hasattr(self.out_account_type, 'to_alipay_dict'):
                params['out_account_type'] = self.out_account_type.to_alipay_dict()
            else:
                params['out_account_type'] = self.out_account_type
        if self.pay_bill_no:
            if hasattr(self.pay_bill_no, 'to_alipay_dict'):
                params['pay_bill_no'] = self.pay_bill_no.to_alipay_dict()
            else:
                params['pay_bill_no'] = self.pay_bill_no
        if self.pay_channel:
            if hasattr(self.pay_channel, 'to_alipay_dict'):
                params['pay_channel'] = self.pay_channel.to_alipay_dict()
            else:
                params['pay_channel'] = self.pay_channel
        if self.pay_fee:
            if hasattr(self.pay_fee, 'to_alipay_dict'):
                params['pay_fee'] = self.pay_fee.to_alipay_dict()
            else:
                params['pay_fee'] = self.pay_fee
        if self.pay_order_no:
            if hasattr(self.pay_order_no, 'to_alipay_dict'):
                params['pay_order_no'] = self.pay_order_no.to_alipay_dict()
            else:
                params['pay_order_no'] = self.pay_order_no
        if self.pay_out_biz_no:
            if hasattr(self.pay_out_biz_no, 'to_alipay_dict'):
                params['pay_out_biz_no'] = self.pay_out_biz_no.to_alipay_dict()
            else:
                params['pay_out_biz_no'] = self.pay_out_biz_no
        if self.pay_time:
            if hasattr(self.pay_time, 'to_alipay_dict'):
                params['pay_time'] = self.pay_time.to_alipay_dict()
            else:
                params['pay_time'] = self.pay_time
        if self.policy_no:
            if hasattr(self.policy_no, 'to_alipay_dict'):
                params['policy_no'] = self.policy_no.to_alipay_dict()
            else:
                params['policy_no'] = self.policy_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ClaimAdvancePaymentDTO()
        if 'claim_no' in d:
            o.claim_no = d['claim_no']
        if 'claim_report_no' in d:
            o.claim_report_no = d['claim_report_no']
        if 'in_account_name' in d:
            o.in_account_name = d['in_account_name']
        if 'in_account_no' in d:
            o.in_account_no = d['in_account_no']
        if 'in_account_type' in d:
            o.in_account_type = d['in_account_type']
        if 'out_account_name' in d:
            o.out_account_name = d['out_account_name']
        if 'out_account_no' in d:
            o.out_account_no = d['out_account_no']
        if 'out_account_type' in d:
            o.out_account_type = d['out_account_type']
        if 'pay_bill_no' in d:
            o.pay_bill_no = d['pay_bill_no']
        if 'pay_channel' in d:
            o.pay_channel = d['pay_channel']
        if 'pay_fee' in d:
            o.pay_fee = d['pay_fee']
        if 'pay_order_no' in d:
            o.pay_order_no = d['pay_order_no']
        if 'pay_out_biz_no' in d:
            o.pay_out_biz_no = d['pay_out_biz_no']
        if 'pay_time' in d:
            o.pay_time = d['pay_time']
        if 'policy_no' in d:
            o.policy_no = d['policy_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityRiskDetectResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityRiskDetectResponse, self).__init__()
        self._risk_code = None
        self._risk_level = None

    @property
    def risk_code(self):
        return self._risk_code

    @risk_code.setter
    def risk_code(self, value):
        self._risk_code = value
    @property
    def risk_level(self):
        return self._risk_level

    @risk_level.setter
    def risk_level(self, value):
        self._risk_level = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityRiskDetectResponse, self).parse_response_content(response_content)
        if 'risk_code' in response:
            self.risk_code = response['risk_code']
        if 'risk_level' in response:
            self.risk_level = response['risk_level']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsDataDsbRequestImageInfo(object):

    def __init__(self):
        self._image_name = None
        self._image_path = None

    @property
    def image_name(self):
        return self._image_name

    @image_name.setter
    def image_name(self, value):
        self._image_name = value
    @property
    def image_path(self):
        return self._image_path

    @image_path.setter
    def image_path(self, value):
        self._image_path = value


    def to_alipay_dict(self):
        params = dict()
        if self.image_name:
            if hasattr(self.image_name, 'to_alipay_dict'):
                params['image_name'] = self.image_name.to_alipay_dict()
            else:
                params['image_name'] = self.image_name
        if self.image_path:
            if hasattr(self.image_path, 'to_alipay_dict'):
                params['image_path'] = self.image_path.to_alipay_dict()
            else:
                params['image_path'] = self.image_path
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsDataDsbRequestImageInfo()
        if 'image_name' in d:
            o.image_name = d['image_name']
        if 'image_path' in d:
            o.image_path = d['image_path']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class JobWorthJobdata(object):

    def __init__(self):
        self._certificate_grant_institution = None
        self._certificate_id = None
        self._certificate_level = None
        self._certificate_name = None
        self._certificate_pic_id = None
        self._company_name = None
        self._degree = None
        self._delivery_position_id = None
        self._delivery_time = None
        self._education_status = None
        self._entry_no = None
        self._exam_score = None
        self._head_pic_id = None
        self._intention_city = None
        self._issue_date = None
        self._job_id = None
        self._job_name = None
        self._ka_job_id = None
        self._ka_job_name = None
        self._ka_profession_id = None
        self._ka_profession_name = None
        self._location = None
        self._month = None
        self._profession_id = None
        self._profession_name = None
        self._salary_max = None
        self._salary_min = None
        self._salary_unit = None
        self._school_name = None
        self._skill_name = None
        self._start_time = None
        self._type = None
        self._valid_date_end = None
        self._valid_date_start = None
        self._verify_status = None
        self._work_desc = None
        self._work_end_time = None
        self._work_property = None
        self._work_start_time = None
        self._year = None

    @property
    def certificate_grant_institution(self):
        return self._certificate_grant_institution

    @certificate_grant_institution.setter
    def certificate_grant_institution(self, value):
        self._certificate_grant_institution = value
    @property
    def certificate_id(self):
        return self._certificate_id

    @certificate_id.setter
    def certificate_id(self, value):
        self._certificate_id = value
    @property
    def certificate_level(self):
        return self._certificate_level

    @certificate_level.setter
    def certificate_level(self, value):
        self._certificate_level = value
    @property
    def certificate_name(self):
        return self._certificate_name

    @certificate_name.setter
    def certificate_name(self, value):
        self._certificate_name = value
    @property
    def certificate_pic_id(self):
        return self._certificate_pic_id

    @certificate_pic_id.setter
    def certificate_pic_id(self, value):
        self._certificate_pic_id = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def degree(self):
        return self._degree

    @degree.setter
    def degree(self, value):
        self._degree = value
    @property
    def delivery_position_id(self):
        return self._delivery_position_id

    @delivery_position_id.setter
    def delivery_position_id(self, value):
        self._delivery_position_id = value
    @property
    def delivery_time(self):
        return self._delivery_time

    @delivery_time.setter
    def delivery_time(self, value):
        self._delivery_time = value
    @property
    def education_status(self):
        return self._education_status

    @education_status.setter
    def education_status(self, value):
        self._education_status = value
    @property
    def entry_no(self):
        return self._entry_no

    @entry_no.setter
    def entry_no(self, value):
        self._entry_no = value
    @property
    def exam_score(self):
        return self._exam_score

    @exam_score.setter
    def exam_score(self, value):
        self._exam_score = value
    @property
    def head_pic_id(self):
        return self._head_pic_id

    @head_pic_id.setter
    def head_pic_id(self, value):
        self._head_pic_id = value
    @property
    def intention_city(self):
        return self._intention_city

    @intention_city.setter
    def intention_city(self, value):
        self._intention_city = value
    @property
    def issue_date(self):
        return self._issue_date

    @issue_date.setter
    def issue_date(self, value):
        self._issue_date = value
    @property
    def job_id(self):
        return self._job_id

    @job_id.setter
    def job_id(self, value):
        self._job_id = value
    @property
    def job_name(self):
        return self._job_name

    @job_name.setter
    def job_name(self, value):
        self._job_name = value
    @property
    def ka_job_id(self):
        return self._ka_job_id

    @ka_job_id.setter
    def ka_job_id(self, value):
        self._ka_job_id = value
    @property
    def ka_job_name(self):
        return self._ka_job_name

    @ka_job_name.setter
    def ka_job_name(self, value):
        self._ka_job_name = value
    @property
    def ka_profession_id(self):
        return self._ka_profession_id

    @ka_profession_id.setter
    def ka_profession_id(self, value):
        self._ka_profession_id = value
    @property
    def ka_profession_name(self):
        return self._ka_profession_name

    @ka_profession_name.setter
    def ka_profession_name(self, value):
        self._ka_profession_name = value
    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, value):
        self._location = value
    @property
    def month(self):
        return self._month

    @month.setter
    def month(self, value):
        self._month = value
    @property
    def profession_id(self):
        return self._profession_id

    @profession_id.setter
    def profession_id(self, value):
        self._profession_id = value
    @property
    def profession_name(self):
        return self._profession_name

    @profession_name.setter
    def profession_name(self, value):
        self._profession_name = value
    @property
    def salary_max(self):
        return self._salary_max

    @salary_max.setter
    def salary_max(self, value):
        self._salary_max = value
    @property
    def salary_min(self):
        return self._salary_min

    @salary_min.setter
    def salary_min(self, value):
        self._salary_min = value
    @property
    def salary_unit(self):
        return self._salary_unit

    @salary_unit.setter
    def salary_unit(self, value):
        self._salary_unit = value
    @property
    def school_name(self):
        return self._school_name

    @school_name.setter
    def school_name(self, value):
        self._school_name = value
    @property
    def skill_name(self):
        return self._skill_name

    @skill_name.setter
    def skill_name(self, value):
        self._skill_name = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def valid_date_end(self):
        return self._valid_date_end

    @valid_date_end.setter
    def valid_date_end(self, value):
        self._valid_date_end = value
    @property
    def valid_date_start(self):
        return self._valid_date_start

    @valid_date_start.setter
    def valid_date_start(self, value):
        self._valid_date_start = value
    @property
    def verify_status(self):
        return self._verify_status

    @verify_status.setter
    def verify_status(self, value):
        self._verify_status = value
    @property
    def work_desc(self):
        return self._work_desc

    @work_desc.setter
    def work_desc(self, value):
        self._work_desc = value
    @property
    def work_end_time(self):
        return self._work_end_time

    @work_end_time.setter
    def work_end_time(self, value):
        self._work_end_time = value
    @property
    def work_property(self):
        return self._work_property

    @work_property.setter
    def work_property(self, value):
        self._work_property = value
    @property
    def work_start_time(self):
        return self._work_start_time

    @work_start_time.setter
    def work_start_time(self, value):
        self._work_start_time = value
    @property
    def year(self):
        return self._year

    @year.setter
    def year(self, value):
        self._year = value


    def to_alipay_dict(self):
        params = dict()
        if self.certificate_grant_institution:
            if hasattr(self.certificate_grant_institution, 'to_alipay_dict'):
                params['certificate_grant_institution'] = self.certificate_grant_institution.to_alipay_dict()
            else:
                params['certificate_grant_institution'] = self.certificate_grant_institution
        if self.certificate_id:
            if hasattr(self.certificate_id, 'to_alipay_dict'):
                params['certificate_id'] = self.certificate_id.to_alipay_dict()
            else:
                params['certificate_id'] = self.certificate_id
        if self.certificate_level:
            if hasattr(self.certificate_level, 'to_alipay_dict'):
                params['certificate_level'] = self.certificate_level.to_alipay_dict()
            else:
                params['certificate_level'] = self.certificate_level
        if self.certificate_name:
            if hasattr(self.certificate_name, 'to_alipay_dict'):
                params['certificate_name'] = self.certificate_name.to_alipay_dict()
            else:
                params['certificate_name'] = self.certificate_name
        if self.certificate_pic_id:
            if hasattr(self.certificate_pic_id, 'to_alipay_dict'):
                params['certificate_pic_id'] = self.certificate_pic_id.to_alipay_dict()
            else:
                params['certificate_pic_id'] = self.certificate_pic_id
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.degree:
            if hasattr(self.degree, 'to_alipay_dict'):
                params['degree'] = self.degree.to_alipay_dict()
            else:
                params['degree'] = self.degree
        if self.delivery_position_id:
            if hasattr(self.delivery_position_id, 'to_alipay_dict'):
                params['delivery_position_id'] = self.delivery_position_id.to_alipay_dict()
            else:
                params['delivery_position_id'] = self.delivery_position_id
        if self.delivery_time:
            if hasattr(self.delivery_time, 'to_alipay_dict'):
                params['delivery_time'] = self.delivery_time.to_alipay_dict()
            else:
                params['delivery_time'] = self.delivery_time
        if self.education_status:
            if hasattr(self.education_status, 'to_alipay_dict'):
                params['education_status'] = self.education_status.to_alipay_dict()
            else:
                params['education_status'] = self.education_status
        if self.entry_no:
            if hasattr(self.entry_no, 'to_alipay_dict'):
                params['entry_no'] = self.entry_no.to_alipay_dict()
            else:
                params['entry_no'] = self.entry_no
        if self.exam_score:
            if hasattr(self.exam_score, 'to_alipay_dict'):
                params['exam_score'] = self.exam_score.to_alipay_dict()
            else:
                params['exam_score'] = self.exam_score
        if self.head_pic_id:
            if hasattr(self.head_pic_id, 'to_alipay_dict'):
                params['head_pic_id'] = self.head_pic_id.to_alipay_dict()
            else:
                params['head_pic_id'] = self.head_pic_id
        if self.intention_city:
            if hasattr(self.intention_city, 'to_alipay_dict'):
                params['intention_city'] = self.intention_city.to_alipay_dict()
            else:
                params['intention_city'] = self.intention_city
        if self.issue_date:
            if hasattr(self.issue_date, 'to_alipay_dict'):
                params['issue_date'] = self.issue_date.to_alipay_dict()
            else:
                params['issue_date'] = self.issue_date
        if self.job_id:
            if hasattr(self.job_id, 'to_alipay_dict'):
                params['job_id'] = self.job_id.to_alipay_dict()
            else:
                params['job_id'] = self.job_id
        if self.job_name:
            if hasattr(self.job_name, 'to_alipay_dict'):
                params['job_name'] = self.job_name.to_alipay_dict()
            else:
                params['job_name'] = self.job_name
        if self.ka_job_id:
            if hasattr(self.ka_job_id, 'to_alipay_dict'):
                params['ka_job_id'] = self.ka_job_id.to_alipay_dict()
            else:
                params['ka_job_id'] = self.ka_job_id
        if self.ka_job_name:
            if hasattr(self.ka_job_name, 'to_alipay_dict'):
                params['ka_job_name'] = self.ka_job_name.to_alipay_dict()
            else:
                params['ka_job_name'] = self.ka_job_name
        if self.ka_profession_id:
            if hasattr(self.ka_profession_id, 'to_alipay_dict'):
                params['ka_profession_id'] = self.ka_profession_id.to_alipay_dict()
            else:
                params['ka_profession_id'] = self.ka_profession_id
        if self.ka_profession_name:
            if hasattr(self.ka_profession_name, 'to_alipay_dict'):
                params['ka_profession_name'] = self.ka_profession_name.to_alipay_dict()
            else:
                params['ka_profession_name'] = self.ka_profession_name
        if self.location:
            if hasattr(self.location, 'to_alipay_dict'):
                params['location'] = self.location.to_alipay_dict()
            else:
                params['location'] = self.location
        if self.month:
            if hasattr(self.month, 'to_alipay_dict'):
                params['month'] = self.month.to_alipay_dict()
            else:
                params['month'] = self.month
        if self.profession_id:
            if hasattr(self.profession_id, 'to_alipay_dict'):
                params['profession_id'] = self.profession_id.to_alipay_dict()
            else:
                params['profession_id'] = self.profession_id
        if self.profession_name:
            if hasattr(self.profession_name, 'to_alipay_dict'):
                params['profession_name'] = self.profession_name.to_alipay_dict()
            else:
                params['profession_name'] = self.profession_name
        if self.salary_max:
            if hasattr(self.salary_max, 'to_alipay_dict'):
                params['salary_max'] = self.salary_max.to_alipay_dict()
            else:
                params['salary_max'] = self.salary_max
        if self.salary_min:
            if hasattr(self.salary_min, 'to_alipay_dict'):
                params['salary_min'] = self.salary_min.to_alipay_dict()
            else:
                params['salary_min'] = self.salary_min
        if self.salary_unit:
            if hasattr(self.salary_unit, 'to_alipay_dict'):
                params['salary_unit'] = self.salary_unit.to_alipay_dict()
            else:
                params['salary_unit'] = self.salary_unit
        if self.school_name:
            if hasattr(self.school_name, 'to_alipay_dict'):
                params['school_name'] = self.school_name.to_alipay_dict()
            else:
                params['school_name'] = self.school_name
        if self.skill_name:
            if hasattr(self.skill_name, 'to_alipay_dict'):
                params['skill_name'] = self.skill_name.to_alipay_dict()
            else:
                params['skill_name'] = self.skill_name
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.valid_date_end:
            if hasattr(self.valid_date_end, 'to_alipay_dict'):
                params['valid_date_end'] = self.valid_date_end.to_alipay_dict()
            else:
                params['valid_date_end'] = self.valid_date_end
        if self.valid_date_start:
            if hasattr(self.valid_date_start, 'to_alipay_dict'):
                params['valid_date_start'] = self.valid_date_start.to_alipay_dict()
            else:
                params['valid_date_start'] = self.valid_date_start
        if self.verify_status:
            if hasattr(self.verify_status, 'to_alipay_dict'):
                params['verify_status'] = self.verify_status.to_alipay_dict()
            else:
                params['verify_status'] = self.verify_status
        if self.work_desc:
            if hasattr(self.work_desc, 'to_alipay_dict'):
                params['work_desc'] = self.work_desc.to_alipay_dict()
            else:
                params['work_desc'] = self.work_desc
        if self.work_end_time:
            if hasattr(self.work_end_time, 'to_alipay_dict'):
                params['work_end_time'] = self.work_end_time.to_alipay_dict()
            else:
                params['work_end_time'] = self.work_end_time
        if self.work_property:
            if hasattr(self.work_property, 'to_alipay_dict'):
                params['work_property'] = self.work_property.to_alipay_dict()
            else:
                params['work_property'] = self.work_property
        if self.work_start_time:
            if hasattr(self.work_start_time, 'to_alipay_dict'):
                params['work_start_time'] = self.work_start_time.to_alipay_dict()
            else:
                params['work_start_time'] = self.work_start_time
        if self.year:
            if hasattr(self.year, 'to_alipay_dict'):
                params['year'] = self.year.to_alipay_dict()
            else:
                params['year'] = self.year
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JobWorthJobdata()
        if 'certificate_grant_institution' in d:
            o.certificate_grant_institution = d['certificate_grant_institution']
        if 'certificate_id' in d:
            o.certificate_id = d['certificate_id']
        if 'certificate_level' in d:
            o.certificate_level = d['certificate_level']
        if 'certificate_name' in d:
            o.certificate_name = d['certificate_name']
        if 'certificate_pic_id' in d:
            o.certificate_pic_id = d['certificate_pic_id']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'degree' in d:
            o.degree = d['degree']
        if 'delivery_position_id' in d:
            o.delivery_position_id = d['delivery_position_id']
        if 'delivery_time' in d:
            o.delivery_time = d['delivery_time']
        if 'education_status' in d:
            o.education_status = d['education_status']
        if 'entry_no' in d:
            o.entry_no = d['entry_no']
        if 'exam_score' in d:
            o.exam_score = d['exam_score']
        if 'head_pic_id' in d:
            o.head_pic_id = d['head_pic_id']
        if 'intention_city' in d:
            o.intention_city = d['intention_city']
        if 'issue_date' in d:
            o.issue_date = d['issue_date']
        if 'job_id' in d:
            o.job_id = d['job_id']
        if 'job_name' in d:
            o.job_name = d['job_name']
        if 'ka_job_id' in d:
            o.ka_job_id = d['ka_job_id']
        if 'ka_job_name' in d:
            o.ka_job_name = d['ka_job_name']
        if 'ka_profession_id' in d:
            o.ka_profession_id = d['ka_profession_id']
        if 'ka_profession_name' in d:
            o.ka_profession_name = d['ka_profession_name']
        if 'location' in d:
            o.location = d['location']
        if 'month' in d:
            o.month = d['month']
        if 'profession_id' in d:
            o.profession_id = d['profession_id']
        if 'profession_name' in d:
            o.profession_name = d['profession_name']
        if 'salary_max' in d:
            o.salary_max = d['salary_max']
        if 'salary_min' in d:
            o.salary_min = d['salary_min']
        if 'salary_unit' in d:
            o.salary_unit = d['salary_unit']
        if 'school_name' in d:
            o.school_name = d['school_name']
        if 'skill_name' in d:
            o.skill_name = d['skill_name']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'type' in d:
            o.type = d['type']
        if 'valid_date_end' in d:
            o.valid_date_end = d['valid_date_end']
        if 'valid_date_start' in d:
            o.valid_date_start = d['valid_date_start']
        if 'verify_status' in d:
            o.verify_status = d['verify_status']
        if 'work_desc' in d:
            o.work_desc = d['work_desc']
        if 'work_end_time' in d:
            o.work_end_time = d['work_end_time']
        if 'work_property' in d:
            o.work_property = d['work_property']
        if 'work_start_time' in d:
            o.work_start_time = d['work_start_time']
        if 'year' in d:
            o.year = d['year']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbdishCommRuleShowInfo(object):

    def __init__(self):
        self._tag_ext_info = None
        self._tag_name = None
        self._tag_value = None

    @property
    def tag_ext_info(self):
        return self._tag_ext_info

    @tag_ext_info.setter
    def tag_ext_info(self, value):
        self._tag_ext_info = value
    @property
    def tag_name(self):
        return self._tag_name

    @tag_name.setter
    def tag_name(self, value):
        self._tag_name = value
    @property
    def tag_value(self):
        return self._tag_value

    @tag_value.setter
    def tag_value(self, value):
        self._tag_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.tag_ext_info:
            if hasattr(self.tag_ext_info, 'to_alipay_dict'):
                params['tag_ext_info'] = self.tag_ext_info.to_alipay_dict()
            else:
                params['tag_ext_info'] = self.tag_ext_info
        if self.tag_name:
            if hasattr(self.tag_name, 'to_alipay_dict'):
                params['tag_name'] = self.tag_name.to_alipay_dict()
            else:
                params['tag_name'] = self.tag_name
        if self.tag_value:
            if hasattr(self.tag_value, 'to_alipay_dict'):
                params['tag_value'] = self.tag_value.to_alipay_dict()
            else:
                params['tag_value'] = self.tag_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishCommRuleShowInfo()
        if 'tag_ext_info' in d:
            o.tag_ext_info = d['tag_ext_info']
        if 'tag_name' in d:
            o.tag_name = d['tag_name']
        if 'tag_value' in d:
            o.tag_value = d['tag_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ApeRecContext import ApeRecContext


class AlipaySecurityLifeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityLifeQueryResponse, self).__init__()
        self._dsfg = None
        self._grt = None
        self._hh = None
        self._jsdfjsd = None
        self._longitude = None
        self._sdgd = None

    @property
    def dsfg(self):
        return self._dsfg

    @dsfg.setter
    def dsfg(self, value):
        if isinstance(value, list):
            self._dsfg = list()
            for i in value:
                if isinstance(i, ApeRecContext):
                    self._dsfg.append(i)
                else:
                    self._dsfg.append(ApeRecContext.from_alipay_dict(i))
    @property
    def grt(self):
        return self._grt

    @grt.setter
    def grt(self, value):
        if isinstance(value, list):
            self._grt = list()
            for i in value:
                self._grt.append(i)
    @property
    def hh(self):
        return self._hh

    @hh.setter
    def hh(self, value):
        if isinstance(value, list):
            self._hh = list()
            for i in value:
                self._hh.append(i)
    @property
    def jsdfjsd(self):
        return self._jsdfjsd

    @jsdfjsd.setter
    def jsdfjsd(self, value):
        self._jsdfjsd = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def sdgd(self):
        return self._sdgd

    @sdgd.setter
    def sdgd(self, value):
        if isinstance(value, list):
            self._sdgd = list()
            for i in value:
                self._sdgd.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityLifeQueryResponse, self).parse_response_content(response_content)
        if 'dsfg' in response:
            self.dsfg = response['dsfg']
        if 'grt' in response:
            self.grt = response['grt']
        if 'hh' in response:
            self.hh = response['hh']
        if 'jsdfjsd' in response:
            self.jsdfjsd = response['jsdfjsd']
        if 'longitude' in response:
            self.longitude = response['longitude']
        if 'sdgd' in response:
            self.sdgd = response['sdgd']
